# coding: utf-8
# Copyright (c) 2016, 2022, Oracle and/or its affiliates.  All rights reserved.
# This software is dual-licensed to you under the Universal Permissive License (UPL) 1.0 as shown at https://oss.oracle.com/licenses/upl or Apache License 2.0 as shown at http://www.apache.org/licenses/LICENSE-2.0. You may choose either license.


from oci.util import formatted_flat_dict, NONE_SENTINEL, value_allowed_none_or_none_sentinel  # noqa: F401
from oci.decorators import init_model_state_from_kwargs


@init_model_state_from_kwargs
class PaySubscriptionDetails(object):
    """
    Request object for paying a subscription
    """

    def __init__(self, **kwargs):
        """
        Initializes a new PaySubscriptionDetails object with values from keyword arguments.
        The following keyword arguments are supported (corresponding to the getters/setters of this class):

        :param subscription:
            The value to assign to the subscription property of this PaySubscriptionDetails.
        :type subscription: oci.osp_gateway.models.Subscription

        :param language_code:
            The value to assign to the language_code property of this PaySubscriptionDetails.
        :type language_code: str

        :param email:
            The value to assign to the email property of this PaySubscriptionDetails.
        :type email: str

        """
        self.swagger_types = {
            'subscription': 'Subscription',
            'language_code': 'str',
            'email': 'str'
        }

        self.attribute_map = {
            'subscription': 'subscription',
            'language_code': 'languageCode',
            'email': 'email'
        }

        self._subscription = None
        self._language_code = None
        self._email = None

    @property
    def subscription(self):
        """
        **[Required]** Gets the subscription of this PaySubscriptionDetails.

        :return: The subscription of this PaySubscriptionDetails.
        :rtype: oci.osp_gateway.models.Subscription
        """
        return self._subscription

    @subscription.setter
    def subscription(self, subscription):
        """
        Sets the subscription of this PaySubscriptionDetails.

        :param subscription: The subscription of this PaySubscriptionDetails.
        :type: oci.osp_gateway.models.Subscription
        """
        self._subscription = subscription

    @property
    def language_code(self):
        """
        **[Required]** Gets the language_code of this PaySubscriptionDetails.
        Language code


        :return: The language_code of this PaySubscriptionDetails.
        :rtype: str
        """
        return self._language_code

    @language_code.setter
    def language_code(self, language_code):
        """
        Sets the language_code of this PaySubscriptionDetails.
        Language code


        :param language_code: The language_code of this PaySubscriptionDetails.
        :type: str
        """
        self._language_code = language_code

    @property
    def email(self):
        """
        **[Required]** Gets the email of this PaySubscriptionDetails.
        User email


        :return: The email of this PaySubscriptionDetails.
        :rtype: str
        """
        return self._email

    @email.setter
    def email(self, email):
        """
        Sets the email of this PaySubscriptionDetails.
        User email


        :param email: The email of this PaySubscriptionDetails.
        :type: str
        """
        self._email = email

    def __repr__(self):
        return formatted_flat_dict(self)

    def __eq__(self, other):
        if other is None:
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        return not self == other



# coding: utf-8
# Copyright (c) 2016, 2022, Oracle and/or its affiliates.  All rights reserved.
# This software is dual-licensed to you under the Universal Permissive License (UPL) 1.0 as shown at https://oss.oracle.com/licenses/upl or Apache License 2.0 as shown at http://www.apache.org/licenses/LICENSE-2.0. You may choose either license.

from .connection_summary import ConnectionSummary
from oci.util import formatted_flat_dict, NONE_SENTINEL, value_allowed_none_or_none_sentinel  # noqa: F401
from oci.decorators import init_model_state_from_kwargs


@init_model_state_from_kwargs
class GithubAccessTokenConnectionSummary(ConnectionSummary):
    """
    Summary information for a connection of the type `GITHUB_ACCESS_TOKEN`.
    This type corresponds to a connection in GitHub that is authenticated with a personal access token.
    """

    def __init__(self, **kwargs):
        """
        Initializes a new GithubAccessTokenConnectionSummary object with values from keyword arguments. The default value of the :py:attr:`~oci.devops.models.GithubAccessTokenConnectionSummary.connection_type` attribute
        of this class is ``GITHUB_ACCESS_TOKEN`` and it should not be changed.
        The following keyword arguments are supported (corresponding to the getters/setters of this class):

        :param id:
            The value to assign to the id property of this GithubAccessTokenConnectionSummary.
        :type id: str

        :param display_name:
            The value to assign to the display_name property of this GithubAccessTokenConnectionSummary.
        :type display_name: str

        :param description:
            The value to assign to the description property of this GithubAccessTokenConnectionSummary.
        :type description: str

        :param compartment_id:
            The value to assign to the compartment_id property of this GithubAccessTokenConnectionSummary.
        :type compartment_id: str

        :param project_id:
            The value to assign to the project_id property of this GithubAccessTokenConnectionSummary.
        :type project_id: str

        :param connection_type:
            The value to assign to the connection_type property of this GithubAccessTokenConnectionSummary.
        :type connection_type: str

        :param time_created:
            The value to assign to the time_created property of this GithubAccessTokenConnectionSummary.
        :type time_created: datetime

        :param time_updated:
            The value to assign to the time_updated property of this GithubAccessTokenConnectionSummary.
        :type time_updated: datetime

        :param lifecycle_state:
            The value to assign to the lifecycle_state property of this GithubAccessTokenConnectionSummary.
        :type lifecycle_state: str

        :param freeform_tags:
            The value to assign to the freeform_tags property of this GithubAccessTokenConnectionSummary.
        :type freeform_tags: dict(str, str)

        :param defined_tags:
            The value to assign to the defined_tags property of this GithubAccessTokenConnectionSummary.
        :type defined_tags: dict(str, dict(str, object))

        :param system_tags:
            The value to assign to the system_tags property of this GithubAccessTokenConnectionSummary.
        :type system_tags: dict(str, dict(str, object))

        :param access_token:
            The value to assign to the access_token property of this GithubAccessTokenConnectionSummary.
        :type access_token: str

        """
        self.swagger_types = {
            'id': 'str',
            'display_name': 'str',
            'description': 'str',
            'compartment_id': 'str',
            'project_id': 'str',
            'connection_type': 'str',
            'time_created': 'datetime',
            'time_updated': 'datetime',
            'lifecycle_state': 'str',
            'freeform_tags': 'dict(str, str)',
            'defined_tags': 'dict(str, dict(str, object))',
            'system_tags': 'dict(str, dict(str, object))',
            'access_token': 'str'
        }

        self.attribute_map = {
            'id': 'id',
            'display_name': 'displayName',
            'description': 'description',
            'compartment_id': 'compartmentId',
            'project_id': 'projectId',
            'connection_type': 'connectionType',
            'time_created': 'timeCreated',
            'time_updated': 'timeUpdated',
            'lifecycle_state': 'lifecycleState',
            'freeform_tags': 'freeformTags',
            'defined_tags': 'definedTags',
            'system_tags': 'systemTags',
            'access_token': 'accessToken'
        }

        self._id = None
        self._display_name = None
        self._description = None
        self._compartment_id = None
        self._project_id = None
        self._connection_type = None
        self._time_created = None
        self._time_updated = None
        self._lifecycle_state = None
        self._freeform_tags = None
        self._defined_tags = None
        self._system_tags = None
        self._access_token = None
        self._connection_type = 'GITHUB_ACCESS_TOKEN'

    @property
    def access_token(self):
        """
        **[Required]** Gets the access_token of this GithubAccessTokenConnectionSummary.
        The OCID of personal access token saved in secret store.


        :return: The access_token of this GithubAccessTokenConnectionSummary.
        :rtype: str
        """
        return self._access_token

    @access_token.setter
    def access_token(self, access_token):
        """
        Sets the access_token of this GithubAccessTokenConnectionSummary.
        The OCID of personal access token saved in secret store.


        :param access_token: The access_token of this GithubAccessTokenConnectionSummary.
        :type: str
        """
        self._access_token = access_token

    def __repr__(self):
        return formatted_flat_dict(self)

    def __eq__(self, other):
        if other is None:
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        return not self == other



# coding: utf-8
# Copyright (c) 2016, 2022, Oracle and/or its affiliates.  All rights reserved.
# This software is dual-licensed to you under the Universal Permissive License (UPL) 1.0 as shown at https://oss.oracle.com/licenses/upl or Apache License 2.0 as shown at http://www.apache.org/licenses/LICENSE-2.0. You may choose either license.


from oci.util import formatted_flat_dict, NONE_SENTINEL, value_allowed_none_or_none_sentinel  # noqa: F401
from oci.decorators import init_model_state_from_kwargs


@init_model_state_from_kwargs
class ResponseCompressionPolicy(object):
    """
    An object that specifies a compression policy for HTTP response from ENABLEMENT POINT to the client.

    This compression policy can be used to enable support for HTTP response compression algorithms like gzip and
    configure the conditions of when a compression algorithm will be used.

    HTTP responses will only be compressed if the client indicates support for one of the enabled compression
    algorithms via the \"Accept-Encoding\" request header.
    """

    def __init__(self, **kwargs):
        """
        Initializes a new ResponseCompressionPolicy object with values from keyword arguments.
        The following keyword arguments are supported (corresponding to the getters/setters of this class):

        :param gzip_compression:
            The value to assign to the gzip_compression property of this ResponseCompressionPolicy.
        :type gzip_compression: oci.waa.models.GzipCompressionPolicy

        """
        self.swagger_types = {
            'gzip_compression': 'GzipCompressionPolicy'
        }

        self.attribute_map = {
            'gzip_compression': 'gzipCompression'
        }

        self._gzip_compression = None

    @property
    def gzip_compression(self):
        """
        Gets the gzip_compression of this ResponseCompressionPolicy.

        :return: The gzip_compression of this ResponseCompressionPolicy.
        :rtype: oci.waa.models.GzipCompressionPolicy
        """
        return self._gzip_compression

    @gzip_compression.setter
    def gzip_compression(self, gzip_compression):
        """
        Sets the gzip_compression of this ResponseCompressionPolicy.

        :param gzip_compression: The gzip_compression of this ResponseCompressionPolicy.
        :type: oci.waa.models.GzipCompressionPolicy
        """
        self._gzip_compression = gzip_compression

    def __repr__(self):
        return formatted_flat_dict(self)

    def __eq__(self, other):
        if other is None:
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        return not self == other



# coding: utf-8
# Copyright (c) 2016, 2022, Oracle and/or its affiliates.  All rights reserved.
# This software is dual-licensed to you under the Universal Permissive License (UPL) 1.0 as shown at https://oss.oracle.com/licenses/upl or Apache License 2.0 as shown at http://www.apache.org/licenses/LICENSE-2.0. You may choose either license.


from oci.util import formatted_flat_dict, NONE_SENTINEL, value_allowed_none_or_none_sentinel  # noqa: F401
from oci.decorators import init_model_state_from_kwargs


@init_model_state_from_kwargs
class VulnerabilitySummary(object):
    """
    Summary of a scan vulnerability
    """

    #: A constant which can be used with the severity property of a VulnerabilitySummary.
    #: This constant has a value of "NONE"
    SEVERITY_NONE = "NONE"

    #: A constant which can be used with the severity property of a VulnerabilitySummary.
    #: This constant has a value of "LOW"
    SEVERITY_LOW = "LOW"

    #: A constant which can be used with the severity property of a VulnerabilitySummary.
    #: This constant has a value of "MEDIUM"
    SEVERITY_MEDIUM = "MEDIUM"

    #: A constant which can be used with the severity property of a VulnerabilitySummary.
    #: This constant has a value of "HIGH"
    SEVERITY_HIGH = "HIGH"

    #: A constant which can be used with the severity property of a VulnerabilitySummary.
    #: This constant has a value of "CRITICAL"
    SEVERITY_CRITICAL = "CRITICAL"

    #: A constant which can be used with the state property of a VulnerabilitySummary.
    #: This constant has a value of "OPEN"
    STATE_OPEN = "OPEN"

    #: A constant which can be used with the state property of a VulnerabilitySummary.
    #: This constant has a value of "FIXED"
    STATE_FIXED = "FIXED"

    #: A constant which can be used with the state property of a VulnerabilitySummary.
    #: This constant has a value of "NOT_APPLICABLE"
    STATE_NOT_APPLICABLE = "NOT_APPLICABLE"

    #: A constant which can be used with the vulnerability_type property of a VulnerabilitySummary.
    #: This constant has a value of "CVE"
    VULNERABILITY_TYPE_CVE = "CVE"

    #: A constant which can be used with the vulnerability_type property of a VulnerabilitySummary.
    #: This constant has a value of "PROBLEM"
    VULNERABILITY_TYPE_PROBLEM = "PROBLEM"

    #: A constant which can be used with the lifecycle_state property of a VulnerabilitySummary.
    #: This constant has a value of "CREATING"
    LIFECYCLE_STATE_CREATING = "CREATING"

    #: A constant which can be used with the lifecycle_state property of a VulnerabilitySummary.
    #: This constant has a value of "UPDATING"
    LIFECYCLE_STATE_UPDATING = "UPDATING"

    #: A constant which can be used with the lifecycle_state property of a VulnerabilitySummary.
    #: This constant has a value of "ACTIVE"
    LIFECYCLE_STATE_ACTIVE = "ACTIVE"

    #: A constant which can be used with the lifecycle_state property of a VulnerabilitySummary.
    #: This constant has a value of "DELETING"
    LIFECYCLE_STATE_DELETING = "DELETING"

    #: A constant which can be used with the lifecycle_state property of a VulnerabilitySummary.
    #: This constant has a value of "DELETED"
    LIFECYCLE_STATE_DELETED = "DELETED"

    #: A constant which can be used with the lifecycle_state property of a VulnerabilitySummary.
    #: This constant has a value of "FAILED"
    LIFECYCLE_STATE_FAILED = "FAILED"

    def __init__(self, **kwargs):
        """
        Initializes a new VulnerabilitySummary object with values from keyword arguments.
        The following keyword arguments are supported (corresponding to the getters/setters of this class):

        :param id:
            The value to assign to the id property of this VulnerabilitySummary.
        :type id: str

        :param compartment_id:
            The value to assign to the compartment_id property of this VulnerabilitySummary.
        :type compartment_id: str

        :param vulnerability_reference:
            The value to assign to the vulnerability_reference property of this VulnerabilitySummary.
        :type vulnerability_reference: str

        :param severity:
            The value to assign to the severity property of this VulnerabilitySummary.
            Allowed values for this property are: "NONE", "LOW", "MEDIUM", "HIGH", "CRITICAL", 'UNKNOWN_ENUM_VALUE'.
            Any unrecognized values returned by a service will be mapped to 'UNKNOWN_ENUM_VALUE'.
        :type severity: str

        :param state:
            The value to assign to the state property of this VulnerabilitySummary.
            Allowed values for this property are: "OPEN", "FIXED", "NOT_APPLICABLE", 'UNKNOWN_ENUM_VALUE'.
            Any unrecognized values returned by a service will be mapped to 'UNKNOWN_ENUM_VALUE'.
        :type state: str

        :param cve_description:
            The value to assign to the cve_description property of this VulnerabilitySummary.
        :type cve_description: str

        :param name:
            The value to assign to the name property of this VulnerabilitySummary.
        :type name: str

        :param time_last_detected:
            The value to assign to the time_last_detected property of this VulnerabilitySummary.
        :type time_last_detected: datetime

        :param time_first_detected:
            The value to assign to the time_first_detected property of this VulnerabilitySummary.
        :type time_first_detected: datetime

        :param impacted_resources_count:
            The value to assign to the impacted_resources_count property of this VulnerabilitySummary.
        :type impacted_resources_count: oci.vulnerability_scanning.models.ImpactedResourcesCount

        :param vulnerability_type:
            The value to assign to the vulnerability_type property of this VulnerabilitySummary.
            Allowed values for this property are: "CVE", "PROBLEM", 'UNKNOWN_ENUM_VALUE'.
            Any unrecognized values returned by a service will be mapped to 'UNKNOWN_ENUM_VALUE'.
        :type vulnerability_type: str

        :param lifecycle_state:
            The value to assign to the lifecycle_state property of this VulnerabilitySummary.
            Allowed values for this property are: "CREATING", "UPDATING", "ACTIVE", "DELETING", "DELETED", "FAILED", 'UNKNOWN_ENUM_VALUE'.
            Any unrecognized values returned by a service will be mapped to 'UNKNOWN_ENUM_VALUE'.
        :type lifecycle_state: str

        """
        self.swagger_types = {
            'id': 'str',
            'compartment_id': 'str',
            'vulnerability_reference': 'str',
            'severity': 'str',
            'state': 'str',
            'cve_description': 'str',
            'name': 'str',
            'time_last_detected': 'datetime',
            'time_first_detected': 'datetime',
            'impacted_resources_count': 'ImpactedResourcesCount',
            'vulnerability_type': 'str',
            'lifecycle_state': 'str'
        }

        self.attribute_map = {
            'id': 'id',
            'compartment_id': 'compartmentId',
            'vulnerability_reference': 'vulnerabilityReference',
            'severity': 'severity',
            'state': 'state',
            'cve_description': 'cveDescription',
            'name': 'name',
            'time_last_detected': 'timeLastDetected',
            'time_first_detected': 'timeFirstDetected',
            'impacted_resources_count': 'impactedResourcesCount',
            'vulnerability_type': 'vulnerabilityType',
            'lifecycle_state': 'lifecycleState'
        }

        self._id = None
        self._compartment_id = None
        self._vulnerability_reference = None
        self._severity = None
        self._state = None
        self._cve_description = None
        self._name = None
        self._time_last_detected = None
        self._time_first_detected = None
        self._impacted_resources_count = None
        self._vulnerability_type = None
        self._lifecycle_state = None

    @property
    def id(self):
        """
        **[Required]** Gets the id of this VulnerabilitySummary.
        ID of the vulnerability


        :return: The id of this VulnerabilitySummary.
        :rtype: str
        """
        return self._id

    @id.setter
    def id(self, id):
        """
        Sets the id of this VulnerabilitySummary.
        ID of the vulnerability


        :param id: The id of this VulnerabilitySummary.
        :type: str
        """
        self._id = id

    @property
    def compartment_id(self):
        """
        **[Required]** Gets the compartment_id of this VulnerabilitySummary.
        Compartment ID of the vulnerability. Vulnerabilities with identical CVEs can exist in different compartments.


        :return: The compartment_id of this VulnerabilitySummary.
        :rtype: str
        """
        return self._compartment_id

    @compartment_id.setter
    def compartment_id(self, compartment_id):
        """
        Sets the compartment_id of this VulnerabilitySummary.
        Compartment ID of the vulnerability. Vulnerabilities with identical CVEs can exist in different compartments.


        :param compartment_id: The compartment_id of this VulnerabilitySummary.
        :type: str
        """
        self._compartment_id = compartment_id

    @property
    def vulnerability_reference(self):
        """
        Gets the vulnerability_reference of this VulnerabilitySummary.
        Reference to the vulnerability type's unique identifier. For CVE, this is the MITRE CVE ID


        :return: The vulnerability_reference of this VulnerabilitySummary.
        :rtype: str
        """
        return self._vulnerability_reference

    @vulnerability_reference.setter
    def vulnerability_reference(self, vulnerability_reference):
        """
        Sets the vulnerability_reference of this VulnerabilitySummary.
        Reference to the vulnerability type's unique identifier. For CVE, this is the MITRE CVE ID


        :param vulnerability_reference: The vulnerability_reference of this VulnerabilitySummary.
        :type: str
        """
        self._vulnerability_reference = vulnerability_reference

    @property
    def severity(self):
        """
        **[Required]** Gets the severity of this VulnerabilitySummary.
        Severity of the vulnerability

        Allowed values for this property are: "NONE", "LOW", "MEDIUM", "HIGH", "CRITICAL", 'UNKNOWN_ENUM_VALUE'.
        Any unrecognized values returned by a service will be mapped to 'UNKNOWN_ENUM_VALUE'.


        :return: The severity of this VulnerabilitySummary.
        :rtype: str
        """
        return self._severity

    @severity.setter
    def severity(self, severity):
        """
        Sets the severity of this VulnerabilitySummary.
        Severity of the vulnerability


        :param severity: The severity of this VulnerabilitySummary.
        :type: str
        """
        allowed_values = ["NONE", "LOW", "MEDIUM", "HIGH", "CRITICAL"]
        if not value_allowed_none_or_none_sentinel(severity, allowed_values):
            severity = 'UNKNOWN_ENUM_VALUE'
        self._severity = severity

    @property
    def state(self):
        """
        Gets the state of this VulnerabilitySummary.
        State of the vulnerability

        Allowed values for this property are: "OPEN", "FIXED", "NOT_APPLICABLE", 'UNKNOWN_ENUM_VALUE'.
        Any unrecognized values returned by a service will be mapped to 'UNKNOWN_ENUM_VALUE'.


        :return: The state of this VulnerabilitySummary.
        :rtype: str
        """
        return self._state

    @state.setter
    def state(self, state):
        """
        Sets the state of this VulnerabilitySummary.
        State of the vulnerability


        :param state: The state of this VulnerabilitySummary.
        :type: str
        """
        allowed_values = ["OPEN", "FIXED", "NOT_APPLICABLE"]
        if not value_allowed_none_or_none_sentinel(state, allowed_values):
            state = 'UNKNOWN_ENUM_VALUE'
        self._state = state

    @property
    def cve_description(self):
        """
        Gets the cve_description of this VulnerabilitySummary.
        The description of CVE vulnerability


        :return: The cve_description of this VulnerabilitySummary.
        :rtype: str
        """
        return self._cve_description

    @cve_description.setter
    def cve_description(self, cve_description):
        """
        Sets the cve_description of this VulnerabilitySummary.
        The description of CVE vulnerability


        :param cve_description: The cve_description of this VulnerabilitySummary.
        :type: str
        """
        self._cve_description = cve_description

    @property
    def name(self):
        """
        **[Required]** Gets the name of this VulnerabilitySummary.
        Vulnerability name


        :return: The name of this VulnerabilitySummary.
        :rtype: str
        """
        return self._name

    @name.setter
    def name(self, name):
        """
        Sets the name of this VulnerabilitySummary.
        Vulnerability name


        :param name: The name of this VulnerabilitySummary.
        :type: str
        """
        self._name = name

    @property
    def time_last_detected(self):
        """
        **[Required]** Gets the time_last_detected of this VulnerabilitySummary.
        Date of scan result that most recently reported the vulnerability


        :return: The time_last_detected of this VulnerabilitySummary.
        :rtype: datetime
        """
        return self._time_last_detected

    @time_last_detected.setter
    def time_last_detected(self, time_last_detected):
        """
        Sets the time_last_detected of this VulnerabilitySummary.
        Date of scan result that most recently reported the vulnerability


        :param time_last_detected: The time_last_detected of this VulnerabilitySummary.
        :type: datetime
        """
        self._time_last_detected = time_last_detected

    @property
    def time_first_detected(self):
        """
        **[Required]** Gets the time_first_detected of this VulnerabilitySummary.
        Date of scan result that first reported the vulnerability


        :return: The time_first_detected of this VulnerabilitySummary.
        :rtype: datetime
        """
        return self._time_first_detected

    @time_first_detected.setter
    def time_first_detected(self, time_first_detected):
        """
        Sets the time_first_detected of this VulnerabilitySummary.
        Date of scan result that first reported the vulnerability


        :param time_first_detected: The time_first_detected of this VulnerabilitySummary.
        :type: datetime
        """
        self._time_first_detected = time_first_detected

    @property
    def impacted_resources_count(self):
        """
        **[Required]** Gets the impacted_resources_count of this VulnerabilitySummary.

        :return: The impacted_resources_count of this VulnerabilitySummary.
        :rtype: oci.vulnerability_scanning.models.ImpactedResourcesCount
        """
        return self._impacted_resources_count

    @impacted_resources_count.setter
    def impacted_resources_count(self, impacted_resources_count):
        """
        Sets the impacted_resources_count of this VulnerabilitySummary.

        :param impacted_resources_count: The impacted_resources_count of this VulnerabilitySummary.
        :type: oci.vulnerability_scanning.models.ImpactedResourcesCount
        """
        self._impacted_resources_count = impacted_resources_count

    @property
    def vulnerability_type(self):
        """
        **[Required]** Gets the vulnerability_type of this VulnerabilitySummary.
        Specifies the type of Vulnerability

        Allowed values for this property are: "CVE", "PROBLEM", 'UNKNOWN_ENUM_VALUE'.
        Any unrecognized values returned by a service will be mapped to 'UNKNOWN_ENUM_VALUE'.


        :return: The vulnerability_type of this VulnerabilitySummary.
        :rtype: str
        """
        return self._vulnerability_type

    @vulnerability_type.setter
    def vulnerability_type(self, vulnerability_type):
        """
        Sets the vulnerability_type of this VulnerabilitySummary.
        Specifies the type of Vulnerability


        :param vulnerability_type: The vulnerability_type of this VulnerabilitySummary.
        :type: str
        """
        allowed_values = ["CVE", "PROBLEM"]
        if not value_allowed_none_or_none_sentinel(vulnerability_type, allowed_values):
            vulnerability_type = 'UNKNOWN_ENUM_VALUE'
        self._vulnerability_type = vulnerability_type

    @property
    def lifecycle_state(self):
        """
        Gets the lifecycle_state of this VulnerabilitySummary.
        The current state of the resource.

        Allowed values for this property are: "CREATING", "UPDATING", "ACTIVE", "DELETING", "DELETED", "FAILED", 'UNKNOWN_ENUM_VALUE'.
        Any unrecognized values returned by a service will be mapped to 'UNKNOWN_ENUM_VALUE'.


        :return: The lifecycle_state of this VulnerabilitySummary.
        :rtype: str
        """
        return self._lifecycle_state

    @lifecycle_state.setter
    def lifecycle_state(self, lifecycle_state):
        """
        Sets the lifecycle_state of this VulnerabilitySummary.
        The current state of the resource.


        :param lifecycle_state: The lifecycle_state of this VulnerabilitySummary.
        :type: str
        """
        allowed_values = ["CREATING", "UPDATING", "ACTIVE", "DELETING", "DELETED", "FAILED"]
        if not value_allowed_none_or_none_sentinel(lifecycle_state, allowed_values):
            lifecycle_state = 'UNKNOWN_ENUM_VALUE'
        self._lifecycle_state = lifecycle_state

    def __repr__(self):
        return formatted_flat_dict(self)

    def __eq__(self, other):
        if other is None:
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        return not self == other



# coding: utf-8
# Copyright (c) 2016, 2022, Oracle and/or its affiliates.  All rights reserved.
# This software is dual-licensed to you under the Universal Permissive License (UPL) 1.0 as shown at https://oss.oracle.com/licenses/upl or Apache License 2.0 as shown at http://www.apache.org/licenses/LICENSE-2.0. You may choose either license.


from oci.util import formatted_flat_dict, NONE_SENTINEL, value_allowed_none_or_none_sentinel  # noqa: F401
from oci.decorators import init_model_state_from_kwargs


@init_model_state_from_kwargs
class PatchInstruction(object):
    """
    A single instruction to be included as part of Patch request content.
    """

    #: A constant which can be used with the operation property of a PatchInstruction.
    #: This constant has a value of "INSERT"
    OPERATION_INSERT = "INSERT"

    #: A constant which can be used with the operation property of a PatchInstruction.
    #: This constant has a value of "REMOVE"
    OPERATION_REMOVE = "REMOVE"

    #: A constant which can be used with the operation property of a PatchInstruction.
    #: This constant has a value of "MERGE"
    OPERATION_MERGE = "MERGE"

    def __init__(self, **kwargs):
        """
        Initializes a new PatchInstruction object with values from keyword arguments. This class has the following subclasses and if you are using this class as input
        to a service operations then you should favor using a subclass over the base class:

        * :class:`~oci.data_safe.models.PatchRemoveInstruction`
        * :class:`~oci.data_safe.models.PatchInsertInstruction`
        * :class:`~oci.data_safe.models.PatchMergeInstruction`

        The following keyword arguments are supported (corresponding to the getters/setters of this class):

        :param operation:
            The value to assign to the operation property of this PatchInstruction.
            Allowed values for this property are: "INSERT", "REMOVE", "MERGE"
        :type operation: str

        :param selection:
            The value to assign to the selection property of this PatchInstruction.
        :type selection: str

        """
        self.swagger_types = {
            'operation': 'str',
            'selection': 'str'
        }

        self.attribute_map = {
            'operation': 'operation',
            'selection': 'selection'
        }

        self._operation = None
        self._selection = None

    @staticmethod
    def get_subtype(object_dictionary):
        """
        Given the hash representation of a subtype of this class,
        use the info in the hash to return the class of the subtype.
        """
        type = object_dictionary['operation']

        if type == 'REMOVE':
            return 'PatchRemoveInstruction'

        if type == 'INSERT':
            return 'PatchInsertInstruction'

        if type == 'MERGE':
            return 'PatchMergeInstruction'
        else:
            return 'PatchInstruction'

    @property
    def operation(self):
        """
        **[Required]** Gets the operation of this PatchInstruction.
        The patch operation.

        Allowed values for this property are: "INSERT", "REMOVE", "MERGE"


        :return: The operation of this PatchInstruction.
        :rtype: str
        """
        return self._operation

    @operation.setter
    def operation(self, operation):
        """
        Sets the operation of this PatchInstruction.
        The patch operation.


        :param operation: The operation of this PatchInstruction.
        :type: str
        """
        allowed_values = ["INSERT", "REMOVE", "MERGE"]
        if not value_allowed_none_or_none_sentinel(operation, allowed_values):
            raise ValueError(
                "Invalid value for `operation`, must be None or one of {0}"
                .format(allowed_values)
            )
        self._operation = operation

    @property
    def selection(self):
        """
        **[Required]** Gets the selection of this PatchInstruction.
        The set of values to which the operation applies as a `JMESPath expression`__ for evaluation against the context resource. An operation fails if the selection yields an exception, except as otherwise specified. Note that comparisons involving non-primitive values (objects or arrays) are not supported and will always evaluate to false.

        __ https://jmespath.org/specification.html


        :return: The selection of this PatchInstruction.
        :rtype: str
        """
        return self._selection

    @selection.setter
    def selection(self, selection):
        """
        Sets the selection of this PatchInstruction.
        The set of values to which the operation applies as a `JMESPath expression`__ for evaluation against the context resource. An operation fails if the selection yields an exception, except as otherwise specified. Note that comparisons involving non-primitive values (objects or arrays) are not supported and will always evaluate to false.

        __ https://jmespath.org/specification.html


        :param selection: The selection of this PatchInstruction.
        :type: str
        """
        self._selection = selection

    def __repr__(self):
        return formatted_flat_dict(self)

    def __eq__(self, other):
        if other is None:
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        return not self == other



# coding: utf-8
# Copyright (c) 2016, 2022, Oracle and/or its affiliates.  All rights reserved.
# This software is dual-licensed to you under the Universal Permissive License (UPL) 1.0 as shown at https://oss.oracle.com/licenses/upl or Apache License 2.0 as shown at http://www.apache.org/licenses/LICENSE-2.0. You may choose either license.


from oci.util import formatted_flat_dict, NONE_SENTINEL, value_allowed_none_or_none_sentinel  # noqa: F401
from oci.decorators import init_model_state_from_kwargs


@init_model_state_from_kwargs
class MaskingReport(object):
    """
    A masking report contains information about a completed masking request. It includes details such as the target database masked,
    masking policy used, masking start and finish time, total number of schemas, tables, columns and values masked, masked columns, and the masking formats used.
    """

    def __init__(self, **kwargs):
        """
        Initializes a new MaskingReport object with values from keyword arguments.
        The following keyword arguments are supported (corresponding to the getters/setters of this class):

        :param id:
            The value to assign to the id property of this MaskingReport.
        :type id: str

        :param compartment_id:
            The value to assign to the compartment_id property of this MaskingReport.
        :type compartment_id: str

        :param masking_work_request_id:
            The value to assign to the masking_work_request_id property of this MaskingReport.
        :type masking_work_request_id: str

        :param masking_policy_id:
            The value to assign to the masking_policy_id property of this MaskingReport.
        :type masking_policy_id: str

        :param target_id:
            The value to assign to the target_id property of this MaskingReport.
        :type target_id: str

        :param total_masked_sensitive_types:
            The value to assign to the total_masked_sensitive_types property of this MaskingReport.
        :type total_masked_sensitive_types: int

        :param total_masked_schemas:
            The value to assign to the total_masked_schemas property of this MaskingReport.
        :type total_masked_schemas: int

        :param total_masked_objects:
            The value to assign to the total_masked_objects property of this MaskingReport.
        :type total_masked_objects: int

        :param total_masked_columns:
            The value to assign to the total_masked_columns property of this MaskingReport.
        :type total_masked_columns: int

        :param total_masked_values:
            The value to assign to the total_masked_values property of this MaskingReport.
        :type total_masked_values: int

        :param time_masking_started:
            The value to assign to the time_masking_started property of this MaskingReport.
        :type time_masking_started: datetime

        :param time_masking_finished:
            The value to assign to the time_masking_finished property of this MaskingReport.
        :type time_masking_finished: datetime

        """
        self.swagger_types = {
            'id': 'str',
            'compartment_id': 'str',
            'masking_work_request_id': 'str',
            'masking_policy_id': 'str',
            'target_id': 'str',
            'total_masked_sensitive_types': 'int',
            'total_masked_schemas': 'int',
            'total_masked_objects': 'int',
            'total_masked_columns': 'int',
            'total_masked_values': 'int',
            'time_masking_started': 'datetime',
            'time_masking_finished': 'datetime'
        }

        self.attribute_map = {
            'id': 'id',
            'compartment_id': 'compartmentId',
            'masking_work_request_id': 'maskingWorkRequestId',
            'masking_policy_id': 'maskingPolicyId',
            'target_id': 'targetId',
            'total_masked_sensitive_types': 'totalMaskedSensitiveTypes',
            'total_masked_schemas': 'totalMaskedSchemas',
            'total_masked_objects': 'totalMaskedObjects',
            'total_masked_columns': 'totalMaskedColumns',
            'total_masked_values': 'totalMaskedValues',
            'time_masking_started': 'timeMaskingStarted',
            'time_masking_finished': 'timeMaskingFinished'
        }

        self._id = None
        self._compartment_id = None
        self._masking_work_request_id = None
        self._masking_policy_id = None
        self._target_id = None
        self._total_masked_sensitive_types = None
        self._total_masked_schemas = None
        self._total_masked_objects = None
        self._total_masked_columns = None
        self._total_masked_values = None
        self._time_masking_started = None
        self._time_masking_finished = None

    @property
    def id(self):
        """
        **[Required]** Gets the id of this MaskingReport.
        The OCID of the masking report.


        :return: The id of this MaskingReport.
        :rtype: str
        """
        return self._id

    @id.setter
    def id(self, id):
        """
        Sets the id of this MaskingReport.
        The OCID of the masking report.


        :param id: The id of this MaskingReport.
        :type: str
        """
        self._id = id

    @property
    def compartment_id(self):
        """
        **[Required]** Gets the compartment_id of this MaskingReport.
        The OCID of the compartment that contains the masking report.


        :return: The compartment_id of this MaskingReport.
        :rtype: str
        """
        return self._compartment_id

    @compartment_id.setter
    def compartment_id(self, compartment_id):
        """
        Sets the compartment_id of this MaskingReport.
        The OCID of the compartment that contains the masking report.


        :param compartment_id: The compartment_id of this MaskingReport.
        :type: str
        """
        self._compartment_id = compartment_id

    @property
    def masking_work_request_id(self):
        """
        **[Required]** Gets the masking_work_request_id of this MaskingReport.
        The OCID of the masking work request that resulted in this masking report.


        :return: The masking_work_request_id of this MaskingReport.
        :rtype: str
        """
        return self._masking_work_request_id

    @masking_work_request_id.setter
    def masking_work_request_id(self, masking_work_request_id):
        """
        Sets the masking_work_request_id of this MaskingReport.
        The OCID of the masking work request that resulted in this masking report.


        :param masking_work_request_id: The masking_work_request_id of this MaskingReport.
        :type: str
        """
        self._masking_work_request_id = masking_work_request_id

    @property
    def masking_policy_id(self):
        """
        **[Required]** Gets the masking_policy_id of this MaskingReport.
        The OCID of the masking policy used.


        :return: The masking_policy_id of this MaskingReport.
        :rtype: str
        """
        return self._masking_policy_id

    @masking_policy_id.setter
    def masking_policy_id(self, masking_policy_id):
        """
        Sets the masking_policy_id of this MaskingReport.
        The OCID of the masking policy used.


        :param masking_policy_id: The masking_policy_id of this MaskingReport.
        :type: str
        """
        self._masking_policy_id = masking_policy_id

    @property
    def target_id(self):
        """
        **[Required]** Gets the target_id of this MaskingReport.
        The OCID of the target database masked.


        :return: The target_id of this MaskingReport.
        :rtype: str
        """
        return self._target_id

    @target_id.setter
    def target_id(self, target_id):
        """
        Sets the target_id of this MaskingReport.
        The OCID of the target database masked.


        :param target_id: The target_id of this MaskingReport.
        :type: str
        """
        self._target_id = target_id

    @property
    def total_masked_sensitive_types(self):
        """
        **[Required]** Gets the total_masked_sensitive_types of this MaskingReport.
        The total number of unique sensitive types associated with the masked columns.


        :return: The total_masked_sensitive_types of this MaskingReport.
        :rtype: int
        """
        return self._total_masked_sensitive_types

    @total_masked_sensitive_types.setter
    def total_masked_sensitive_types(self, total_masked_sensitive_types):
        """
        Sets the total_masked_sensitive_types of this MaskingReport.
        The total number of unique sensitive types associated with the masked columns.


        :param total_masked_sensitive_types: The total_masked_sensitive_types of this MaskingReport.
        :type: int
        """
        self._total_masked_sensitive_types = total_masked_sensitive_types

    @property
    def total_masked_schemas(self):
        """
        **[Required]** Gets the total_masked_schemas of this MaskingReport.
        The total number of unique schemas that contain the masked columns.


        :return: The total_masked_schemas of this MaskingReport.
        :rtype: int
        """
        return self._total_masked_schemas

    @total_masked_schemas.setter
    def total_masked_schemas(self, total_masked_schemas):
        """
        Sets the total_masked_schemas of this MaskingReport.
        The total number of unique schemas that contain the masked columns.


        :param total_masked_schemas: The total_masked_schemas of this MaskingReport.
        :type: int
        """
        self._total_masked_schemas = total_masked_schemas

    @property
    def total_masked_objects(self):
        """
        **[Required]** Gets the total_masked_objects of this MaskingReport.
        The total number of unique objects (tables and editioning views) that contain the masked columns.


        :return: The total_masked_objects of this MaskingReport.
        :rtype: int
        """
        return self._total_masked_objects

    @total_masked_objects.setter
    def total_masked_objects(self, total_masked_objects):
        """
        Sets the total_masked_objects of this MaskingReport.
        The total number of unique objects (tables and editioning views) that contain the masked columns.


        :param total_masked_objects: The total_masked_objects of this MaskingReport.
        :type: int
        """
        self._total_masked_objects = total_masked_objects

    @property
    def total_masked_columns(self):
        """
        **[Required]** Gets the total_masked_columns of this MaskingReport.
        The total number of masked columns.


        :return: The total_masked_columns of this MaskingReport.
        :rtype: int
        """
        return self._total_masked_columns

    @total_masked_columns.setter
    def total_masked_columns(self, total_masked_columns):
        """
        Sets the total_masked_columns of this MaskingReport.
        The total number of masked columns.


        :param total_masked_columns: The total_masked_columns of this MaskingReport.
        :type: int
        """
        self._total_masked_columns = total_masked_columns

    @property
    def total_masked_values(self):
        """
        **[Required]** Gets the total_masked_values of this MaskingReport.
        The total number of masked values.


        :return: The total_masked_values of this MaskingReport.
        :rtype: int
        """
        return self._total_masked_values

    @total_masked_values.setter
    def total_masked_values(self, total_masked_values):
        """
        Sets the total_masked_values of this MaskingReport.
        The total number of masked values.


        :param total_masked_values: The total_masked_values of this MaskingReport.
        :type: int
        """
        self._total_masked_values = total_masked_values

    @property
    def time_masking_started(self):
        """
        **[Required]** Gets the time_masking_started of this MaskingReport.
        The date and time data masking started, in the format defined by `RFC3339`__

        __ https://tools.ietf.org/html/rfc3339


        :return: The time_masking_started of this MaskingReport.
        :rtype: datetime
        """
        return self._time_masking_started

    @time_masking_started.setter
    def time_masking_started(self, time_masking_started):
        """
        Sets the time_masking_started of this MaskingReport.
        The date and time data masking started, in the format defined by `RFC3339`__

        __ https://tools.ietf.org/html/rfc3339


        :param time_masking_started: The time_masking_started of this MaskingReport.
        :type: datetime
        """
        self._time_masking_started = time_masking_started

    @property
    def time_masking_finished(self):
        """
        **[Required]** Gets the time_masking_finished of this MaskingReport.
        The date and time data masking finished, in the format defined by `RFC3339`__

        __ https://tools.ietf.org/html/rfc3339


        :return: The time_masking_finished of this MaskingReport.
        :rtype: datetime
        """
        return self._time_masking_finished

    @time_masking_finished.setter
    def time_masking_finished(self, time_masking_finished):
        """
        Sets the time_masking_finished of this MaskingReport.
        The date and time data masking finished, in the format defined by `RFC3339`__

        __ https://tools.ietf.org/html/rfc3339


        :param time_masking_finished: The time_masking_finished of this MaskingReport.
        :type: datetime
        """
        self._time_masking_finished = time_masking_finished

    def __repr__(self):
        return formatted_flat_dict(self)

    def __eq__(self, other):
        if other is None:
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        return not self == other



# coding: utf-8
# Copyright (c) 2016, 2022, Oracle and/or its affiliates.  All rights reserved.
# This software is dual-licensed to you under the Universal Permissive License (UPL) 1.0 as shown at https://oss.oracle.com/licenses/upl or Apache License 2.0 as shown at http://www.apache.org/licenses/LICENSE-2.0. You may choose either license.

from .update_channel_details import UpdateChannelDetails
from oci.util import formatted_flat_dict, NONE_SENTINEL, value_allowed_none_or_none_sentinel  # noqa: F401
from oci.decorators import init_model_state_from_kwargs


@init_model_state_from_kwargs
class UpdateOSSChannelDetails(UpdateChannelDetails):
    """
    Properties to update an Oracle Streaming Service (OSS) channel.
    """

    def __init__(self, **kwargs):
        """
        Initializes a new UpdateOSSChannelDetails object with values from keyword arguments. The default value of the :py:attr:`~oci.oda.models.UpdateOSSChannelDetails.type` attribute
        of this class is ``OSS`` and it should not be changed.
        The following keyword arguments are supported (corresponding to the getters/setters of this class):

        :param description:
            The value to assign to the description property of this UpdateOSSChannelDetails.
        :type description: str

        :param type:
            The value to assign to the type property of this UpdateOSSChannelDetails.
            Allowed values for this property are: "ANDROID", "APPEVENT", "APPLICATION", "CORTANA", "FACEBOOK", "IOS", "MSTEAMS", "OSS", "OSVC", "SERVICECLOUD", "SLACK", "TEST", "TWILIO", "WEB", "WEBHOOK"
        :type type: str

        :param session_expiry_duration_in_milliseconds:
            The value to assign to the session_expiry_duration_in_milliseconds property of this UpdateOSSChannelDetails.
        :type session_expiry_duration_in_milliseconds: int

        :param freeform_tags:
            The value to assign to the freeform_tags property of this UpdateOSSChannelDetails.
        :type freeform_tags: dict(str, str)

        :param defined_tags:
            The value to assign to the defined_tags property of this UpdateOSSChannelDetails.
        :type defined_tags: dict(str, dict(str, object))

        :param event_sink_bot_ids:
            The value to assign to the event_sink_bot_ids property of this UpdateOSSChannelDetails.
        :type event_sink_bot_ids: list[str]

        :param inbound_message_topic:
            The value to assign to the inbound_message_topic property of this UpdateOSSChannelDetails.
        :type inbound_message_topic: str

        :param outbound_message_topic:
            The value to assign to the outbound_message_topic property of this UpdateOSSChannelDetails.
        :type outbound_message_topic: str

        :param bootstrap_servers:
            The value to assign to the bootstrap_servers property of this UpdateOSSChannelDetails.
        :type bootstrap_servers: str

        :param security_protocol:
            The value to assign to the security_protocol property of this UpdateOSSChannelDetails.
        :type security_protocol: str

        :param sasl_mechanism:
            The value to assign to the sasl_mechanism property of this UpdateOSSChannelDetails.
        :type sasl_mechanism: str

        :param tenancy_name:
            The value to assign to the tenancy_name property of this UpdateOSSChannelDetails.
        :type tenancy_name: str

        :param user_name:
            The value to assign to the user_name property of this UpdateOSSChannelDetails.
        :type user_name: str

        :param stream_pool_id:
            The value to assign to the stream_pool_id property of this UpdateOSSChannelDetails.
        :type stream_pool_id: str

        :param auth_token:
            The value to assign to the auth_token property of this UpdateOSSChannelDetails.
        :type auth_token: str

        """
        self.swagger_types = {
            'description': 'str',
            'type': 'str',
            'session_expiry_duration_in_milliseconds': 'int',
            'freeform_tags': 'dict(str, str)',
            'defined_tags': 'dict(str, dict(str, object))',
            'event_sink_bot_ids': 'list[str]',
            'inbound_message_topic': 'str',
            'outbound_message_topic': 'str',
            'bootstrap_servers': 'str',
            'security_protocol': 'str',
            'sasl_mechanism': 'str',
            'tenancy_name': 'str',
            'user_name': 'str',
            'stream_pool_id': 'str',
            'auth_token': 'str'
        }

        self.attribute_map = {
            'description': 'description',
            'type': 'type',
            'session_expiry_duration_in_milliseconds': 'sessionExpiryDurationInMilliseconds',
            'freeform_tags': 'freeformTags',
            'defined_tags': 'definedTags',
            'event_sink_bot_ids': 'eventSinkBotIds',
            'inbound_message_topic': 'inboundMessageTopic',
            'outbound_message_topic': 'outboundMessageTopic',
            'bootstrap_servers': 'bootstrapServers',
            'security_protocol': 'securityProtocol',
            'sasl_mechanism': 'saslMechanism',
            'tenancy_name': 'tenancyName',
            'user_name': 'userName',
            'stream_pool_id': 'streamPoolId',
            'auth_token': 'authToken'
        }

        self._description = None
        self._type = None
        self._session_expiry_duration_in_milliseconds = None
        self._freeform_tags = None
        self._defined_tags = None
        self._event_sink_bot_ids = None
        self._inbound_message_topic = None
        self._outbound_message_topic = None
        self._bootstrap_servers = None
        self._security_protocol = None
        self._sasl_mechanism = None
        self._tenancy_name = None
        self._user_name = None
        self._stream_pool_id = None
        self._auth_token = None
        self._type = 'OSS'

    @property
    def event_sink_bot_ids(self):
        """
        Gets the event_sink_bot_ids of this UpdateOSSChannelDetails.
        The IDs of the Skills and Digital Assistants that the Channel is routed to.


        :return: The event_sink_bot_ids of this UpdateOSSChannelDetails.
        :rtype: list[str]
        """
        return self._event_sink_bot_ids

    @event_sink_bot_ids.setter
    def event_sink_bot_ids(self, event_sink_bot_ids):
        """
        Sets the event_sink_bot_ids of this UpdateOSSChannelDetails.
        The IDs of the Skills and Digital Assistants that the Channel is routed to.


        :param event_sink_bot_ids: The event_sink_bot_ids of this UpdateOSSChannelDetails.
        :type: list[str]
        """
        self._event_sink_bot_ids = event_sink_bot_ids

    @property
    def inbound_message_topic(self):
        """
        Gets the inbound_message_topic of this UpdateOSSChannelDetails.
        The topic inbound messages are received on.


        :return: The inbound_message_topic of this UpdateOSSChannelDetails.
        :rtype: str
        """
        return self._inbound_message_topic

    @inbound_message_topic.setter
    def inbound_message_topic(self, inbound_message_topic):
        """
        Sets the inbound_message_topic of this UpdateOSSChannelDetails.
        The topic inbound messages are received on.


        :param inbound_message_topic: The inbound_message_topic of this UpdateOSSChannelDetails.
        :type: str
        """
        self._inbound_message_topic = inbound_message_topic

    @property
    def outbound_message_topic(self):
        """
        Gets the outbound_message_topic of this UpdateOSSChannelDetails.
        The topic outbound messages are sent on.


        :return: The outbound_message_topic of this UpdateOSSChannelDetails.
        :rtype: str
        """
        return self._outbound_message_topic

    @outbound_message_topic.setter
    def outbound_message_topic(self, outbound_message_topic):
        """
        Sets the outbound_message_topic of this UpdateOSSChannelDetails.
        The topic outbound messages are sent on.


        :param outbound_message_topic: The outbound_message_topic of this UpdateOSSChannelDetails.
        :type: str
        """
        self._outbound_message_topic = outbound_message_topic

    @property
    def bootstrap_servers(self):
        """
        Gets the bootstrap_servers of this UpdateOSSChannelDetails.
        The Oracle Streaming Service bootstrap servers.


        :return: The bootstrap_servers of this UpdateOSSChannelDetails.
        :rtype: str
        """
        return self._bootstrap_servers

    @bootstrap_servers.setter
    def bootstrap_servers(self, bootstrap_servers):
        """
        Sets the bootstrap_servers of this UpdateOSSChannelDetails.
        The Oracle Streaming Service bootstrap servers.


        :param bootstrap_servers: The bootstrap_servers of this UpdateOSSChannelDetails.
        :type: str
        """
        self._bootstrap_servers = bootstrap_servers

    @property
    def security_protocol(self):
        """
        Gets the security_protocol of this UpdateOSSChannelDetails.
        The security protocol to use when conecting to the Oracle Streaming Service. See Oracle Streaming Service documentation for a list of valid values.


        :return: The security_protocol of this UpdateOSSChannelDetails.
        :rtype: str
        """
        return self._security_protocol

    @security_protocol.setter
    def security_protocol(self, security_protocol):
        """
        Sets the security_protocol of this UpdateOSSChannelDetails.
        The security protocol to use when conecting to the Oracle Streaming Service. See Oracle Streaming Service documentation for a list of valid values.


        :param security_protocol: The security_protocol of this UpdateOSSChannelDetails.
        :type: str
        """
        self._security_protocol = security_protocol

    @property
    def sasl_mechanism(self):
        """
        Gets the sasl_mechanism of this UpdateOSSChannelDetails.
        The SASL mechanmism to use when conecting to the Oracle Streaming Service. See Oracle Streaming Service documentation for a list of valid values.


        :return: The sasl_mechanism of this UpdateOSSChannelDetails.
        :rtype: str
        """
        return self._sasl_mechanism

    @sasl_mechanism.setter
    def sasl_mechanism(self, sasl_mechanism):
        """
        Sets the sasl_mechanism of this UpdateOSSChannelDetails.
        The SASL mechanmism to use when conecting to the Oracle Streaming Service. See Oracle Streaming Service documentation for a list of valid values.


        :param sasl_mechanism: The sasl_mechanism of this UpdateOSSChannelDetails.
        :type: str
        """
        self._sasl_mechanism = sasl_mechanism

    @property
    def tenancy_name(self):
        """
        Gets the tenancy_name of this UpdateOSSChannelDetails.
        The tenancy to use when connecting to the Oracle Streaming Service.


        :return: The tenancy_name of this UpdateOSSChannelDetails.
        :rtype: str
        """
        return self._tenancy_name

    @tenancy_name.setter
    def tenancy_name(self, tenancy_name):
        """
        Sets the tenancy_name of this UpdateOSSChannelDetails.
        The tenancy to use when connecting to the Oracle Streaming Service.


        :param tenancy_name: The tenancy_name of this UpdateOSSChannelDetails.
        :type: str
        """
        self._tenancy_name = tenancy_name

    @property
    def user_name(self):
        """
        Gets the user_name of this UpdateOSSChannelDetails.
        The user name to use when connecting to the Oracle Streaming Service.


        :return: The user_name of this UpdateOSSChannelDetails.
        :rtype: str
        """
        return self._user_name

    @user_name.setter
    def user_name(self, user_name):
        """
        Sets the user_name of this UpdateOSSChannelDetails.
        The user name to use when connecting to the Oracle Streaming Service.


        :param user_name: The user_name of this UpdateOSSChannelDetails.
        :type: str
        """
        self._user_name = user_name

    @property
    def stream_pool_id(self):
        """
        Gets the stream_pool_id of this UpdateOSSChannelDetails.
        The stream pool OCI to use when connecting to the Oracle Streaming Service.


        :return: The stream_pool_id of this UpdateOSSChannelDetails.
        :rtype: str
        """
        return self._stream_pool_id

    @stream_pool_id.setter
    def stream_pool_id(self, stream_pool_id):
        """
        Sets the stream_pool_id of this UpdateOSSChannelDetails.
        The stream pool OCI to use when connecting to the Oracle Streaming Service.


        :param stream_pool_id: The stream_pool_id of this UpdateOSSChannelDetails.
        :type: str
        """
        self._stream_pool_id = stream_pool_id

    @property
    def auth_token(self):
        """
        Gets the auth_token of this UpdateOSSChannelDetails.
        The authentication token to use when connecting to the Oracle Streaming Service.


        :return: The auth_token of this UpdateOSSChannelDetails.
        :rtype: str
        """
        return self._auth_token

    @auth_token.setter
    def auth_token(self, auth_token):
        """
        Sets the auth_token of this UpdateOSSChannelDetails.
        The authentication token to use when connecting to the Oracle Streaming Service.


        :param auth_token: The auth_token of this UpdateOSSChannelDetails.
        :type: str
        """
        self._auth_token = auth_token

    def __repr__(self):
        return formatted_flat_dict(self)

    def __eq__(self, other):
        if other is None:
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        return not self == other



# coding: utf-8
# Copyright (c) 2016, 2022, Oracle and/or its affiliates.  All rights reserved.
# This software is dual-licensed to you under the Universal Permissive License (UPL) 1.0 as shown at https://oss.oracle.com/licenses/upl or Apache License 2.0 as shown at http://www.apache.org/licenses/LICENSE-2.0. You may choose either license.


from oci.util import formatted_flat_dict, NONE_SENTINEL, value_allowed_none_or_none_sentinel  # noqa: F401
from oci.decorators import init_model_state_from_kwargs


@init_model_state_from_kwargs
class AttachmentDetails(object):
    """
    Description of an attachments for this instance
    """

    #: A constant which can be used with the target_role property of a AttachmentDetails.
    #: This constant has a value of "PARENT"
    TARGET_ROLE_PARENT = "PARENT"

    #: A constant which can be used with the target_role property of a AttachmentDetails.
    #: This constant has a value of "CHILD"
    TARGET_ROLE_CHILD = "CHILD"

    def __init__(self, **kwargs):
        """
        Initializes a new AttachmentDetails object with values from keyword arguments.
        The following keyword arguments are supported (corresponding to the getters/setters of this class):

        :param target_role:
            The value to assign to the target_role property of this AttachmentDetails.
            Allowed values for this property are: "PARENT", "CHILD", 'UNKNOWN_ENUM_VALUE'.
            Any unrecognized values returned by a service will be mapped to 'UNKNOWN_ENUM_VALUE'.
        :type target_role: str

        :param is_implicit:
            The value to assign to the is_implicit property of this AttachmentDetails.
        :type is_implicit: bool

        :param target_id:
            The value to assign to the target_id property of this AttachmentDetails.
        :type target_id: str

        :param target_instance_url:
            The value to assign to the target_instance_url property of this AttachmentDetails.
        :type target_instance_url: str

        :param target_service_type:
            The value to assign to the target_service_type property of this AttachmentDetails.
        :type target_service_type: str

        """
        self.swagger_types = {
            'target_role': 'str',
            'is_implicit': 'bool',
            'target_id': 'str',
            'target_instance_url': 'str',
            'target_service_type': 'str'
        }

        self.attribute_map = {
            'target_role': 'targetRole',
            'is_implicit': 'isImplicit',
            'target_id': 'targetId',
            'target_instance_url': 'targetInstanceUrl',
            'target_service_type': 'targetServiceType'
        }

        self._target_role = None
        self._is_implicit = None
        self._target_id = None
        self._target_instance_url = None
        self._target_service_type = None

    @property
    def target_role(self):
        """
        **[Required]** Gets the target_role of this AttachmentDetails.
        The role of the target attachment.
           * `PARENT` - The target instance is the parent of this attachment.
           * `CHILD` - The target instance is the child of this attachment.

        Allowed values for this property are: "PARENT", "CHILD", 'UNKNOWN_ENUM_VALUE'.
        Any unrecognized values returned by a service will be mapped to 'UNKNOWN_ENUM_VALUE'.


        :return: The target_role of this AttachmentDetails.
        :rtype: str
        """
        return self._target_role

    @target_role.setter
    def target_role(self, target_role):
        """
        Sets the target_role of this AttachmentDetails.
        The role of the target attachment.
           * `PARENT` - The target instance is the parent of this attachment.
           * `CHILD` - The target instance is the child of this attachment.


        :param target_role: The target_role of this AttachmentDetails.
        :type: str
        """
        allowed_values = ["PARENT", "CHILD"]
        if not value_allowed_none_or_none_sentinel(target_role, allowed_values):
            target_role = 'UNKNOWN_ENUM_VALUE'
        self._target_role = target_role

    @property
    def is_implicit(self):
        """
        **[Required]** Gets the is_implicit of this AttachmentDetails.
        * If role == `PARENT`, the attached instance was created by this service instance
        * If role == `CHILD`, this instance was created from attached instance on behalf of a user


        :return: The is_implicit of this AttachmentDetails.
        :rtype: bool
        """
        return self._is_implicit

    @is_implicit.setter
    def is_implicit(self, is_implicit):
        """
        Sets the is_implicit of this AttachmentDetails.
        * If role == `PARENT`, the attached instance was created by this service instance
        * If role == `CHILD`, this instance was created from attached instance on behalf of a user


        :param is_implicit: The is_implicit of this AttachmentDetails.
        :type: bool
        """
        self._is_implicit = is_implicit

    @property
    def target_id(self):
        """
        **[Required]** Gets the target_id of this AttachmentDetails.
        The OCID of the target instance (which could be any other OCI PaaS/SaaS resource), to which this instance is attached.


        :return: The target_id of this AttachmentDetails.
        :rtype: str
        """
        return self._target_id

    @target_id.setter
    def target_id(self, target_id):
        """
        Sets the target_id of this AttachmentDetails.
        The OCID of the target instance (which could be any other OCI PaaS/SaaS resource), to which this instance is attached.


        :param target_id: The target_id of this AttachmentDetails.
        :type: str
        """
        self._target_id = target_id

    @property
    def target_instance_url(self):
        """
        **[Required]** Gets the target_instance_url of this AttachmentDetails.
        The dataplane instance URL of the attached instance


        :return: The target_instance_url of this AttachmentDetails.
        :rtype: str
        """
        return self._target_instance_url

    @target_instance_url.setter
    def target_instance_url(self, target_instance_url):
        """
        Sets the target_instance_url of this AttachmentDetails.
        The dataplane instance URL of the attached instance


        :param target_instance_url: The target_instance_url of this AttachmentDetails.
        :type: str
        """
        self._target_instance_url = target_instance_url

    @property
    def target_service_type(self):
        """
        **[Required]** Gets the target_service_type of this AttachmentDetails.
        The type of the target instance, such as \"FUSION\".


        :return: The target_service_type of this AttachmentDetails.
        :rtype: str
        """
        return self._target_service_type

    @target_service_type.setter
    def target_service_type(self, target_service_type):
        """
        Sets the target_service_type of this AttachmentDetails.
        The type of the target instance, such as \"FUSION\".


        :param target_service_type: The target_service_type of this AttachmentDetails.
        :type: str
        """
        self._target_service_type = target_service_type

    def __repr__(self):
        return formatted_flat_dict(self)

    def __eq__(self, other):
        if other is None:
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        return not self == other



# coding: utf-8
# Copyright (c) 2016, 2022, Oracle and/or its affiliates.  All rights reserved.
# This software is dual-licensed to you under the Universal Permissive License (UPL) 1.0 as shown at https://oss.oracle.com/licenses/upl or Apache License 2.0 as shown at http://www.apache.org/licenses/LICENSE-2.0. You may choose either license.


from oci.util import formatted_flat_dict, NONE_SENTINEL, value_allowed_none_or_none_sentinel  # noqa: F401
from oci.decorators import init_model_state_from_kwargs


@init_model_state_from_kwargs
class NodeSourceOption(object):
    """
    The source option for the node.
    """

    #: A constant which can be used with the source_type property of a NodeSourceOption.
    #: This constant has a value of "IMAGE"
    SOURCE_TYPE_IMAGE = "IMAGE"

    def __init__(self, **kwargs):
        """
        Initializes a new NodeSourceOption object with values from keyword arguments. This class has the following subclasses and if you are using this class as input
        to a service operations then you should favor using a subclass over the base class:

        * :class:`~oci.container_engine.models.NodeSourceViaImageOption`

        The following keyword arguments are supported (corresponding to the getters/setters of this class):

        :param source_type:
            The value to assign to the source_type property of this NodeSourceOption.
            Allowed values for this property are: "IMAGE", 'UNKNOWN_ENUM_VALUE'.
            Any unrecognized values returned by a service will be mapped to 'UNKNOWN_ENUM_VALUE'.
        :type source_type: str

        :param source_name:
            The value to assign to the source_name property of this NodeSourceOption.
        :type source_name: str

        """
        self.swagger_types = {
            'source_type': 'str',
            'source_name': 'str'
        }

        self.attribute_map = {
            'source_type': 'sourceType',
            'source_name': 'sourceName'
        }

        self._source_type = None
        self._source_name = None

    @staticmethod
    def get_subtype(object_dictionary):
        """
        Given the hash representation of a subtype of this class,
        use the info in the hash to return the class of the subtype.
        """
        type = object_dictionary['sourceType']

        if type == 'IMAGE':
            return 'NodeSourceViaImageOption'
        else:
            return 'NodeSourceOption'

    @property
    def source_type(self):
        """
        **[Required]** Gets the source_type of this NodeSourceOption.
        The source type of this option.
        `IMAGE` means the OCID is of an image.

        Allowed values for this property are: "IMAGE", 'UNKNOWN_ENUM_VALUE'.
        Any unrecognized values returned by a service will be mapped to 'UNKNOWN_ENUM_VALUE'.


        :return: The source_type of this NodeSourceOption.
        :rtype: str
        """
        return self._source_type

    @source_type.setter
    def source_type(self, source_type):
        """
        Sets the source_type of this NodeSourceOption.
        The source type of this option.
        `IMAGE` means the OCID is of an image.


        :param source_type: The source_type of this NodeSourceOption.
        :type: str
        """
        allowed_values = ["IMAGE"]
        if not value_allowed_none_or_none_sentinel(source_type, allowed_values):
            source_type = 'UNKNOWN_ENUM_VALUE'
        self._source_type = source_type

    @property
    def source_name(self):
        """
        Gets the source_name of this NodeSourceOption.
        The user-friendly name of the entity corresponding to the OCID.


        :return: The source_name of this NodeSourceOption.
        :rtype: str
        """
        return self._source_name

    @source_name.setter
    def source_name(self, source_name):
        """
        Sets the source_name of this NodeSourceOption.
        The user-friendly name of the entity corresponding to the OCID.


        :param source_name: The source_name of this NodeSourceOption.
        :type: str
        """
        self._source_name = source_name

    def __repr__(self):
        return formatted_flat_dict(self)

    def __eq__(self, other):
        if other is None:
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        return not self == other



# coding: utf-8
# Copyright (c) 2016, 2022, Oracle and/or its affiliates.  All rights reserved.
# This software is dual-licensed to you under the Universal Permissive License (UPL) 1.0 as shown at https://oss.oracle.com/licenses/upl or Apache License 2.0 as shown at http://www.apache.org/licenses/LICENSE-2.0. You may choose either license.


from oci.util import formatted_flat_dict, NONE_SENTINEL, value_allowed_none_or_none_sentinel  # noqa: F401
from oci.decorators import init_model_state_from_kwargs


@init_model_state_from_kwargs
class RenameDatasetLabelsDetails(object):
    """
    Renames a subset of Labels in the Dataset's LabelSet.  The Labels in the source LabelSet will be replaced with the Labels in the target LabelSet.
    Labels are correlated by index, i.e. the first Label in the source LabelSet will be replaced by the first Label in the target LabelSet.
    If the size of the\u00A0source and target LabelSets are not equal, the request will be rejected.
    """

    def __init__(self, **kwargs):
        """
        Initializes a new RenameDatasetLabelsDetails object with values from keyword arguments.
        The following keyword arguments are supported (corresponding to the getters/setters of this class):

        :param source_label_set:
            The value to assign to the source_label_set property of this RenameDatasetLabelsDetails.
        :type source_label_set: oci.data_labeling_service.models.LabelSet

        :param target_label_set:
            The value to assign to the target_label_set property of this RenameDatasetLabelsDetails.
        :type target_label_set: oci.data_labeling_service.models.LabelSet

        """
        self.swagger_types = {
            'source_label_set': 'LabelSet',
            'target_label_set': 'LabelSet'
        }

        self.attribute_map = {
            'source_label_set': 'sourceLabelSet',
            'target_label_set': 'targetLabelSet'
        }

        self._source_label_set = None
        self._target_label_set = None

    @property
    def source_label_set(self):
        """
        Gets the source_label_set of this RenameDatasetLabelsDetails.

        :return: The source_label_set of this RenameDatasetLabelsDetails.
        :rtype: oci.data_labeling_service.models.LabelSet
        """
        return self._source_label_set

    @source_label_set.setter
    def source_label_set(self, source_label_set):
        """
        Sets the source_label_set of this RenameDatasetLabelsDetails.

        :param source_label_set: The source_label_set of this RenameDatasetLabelsDetails.
        :type: oci.data_labeling_service.models.LabelSet
        """
        self._source_label_set = source_label_set

    @property
    def target_label_set(self):
        """
        Gets the target_label_set of this RenameDatasetLabelsDetails.

        :return: The target_label_set of this RenameDatasetLabelsDetails.
        :rtype: oci.data_labeling_service.models.LabelSet
        """
        return self._target_label_set

    @target_label_set.setter
    def target_label_set(self, target_label_set):
        """
        Sets the target_label_set of this RenameDatasetLabelsDetails.

        :param target_label_set: The target_label_set of this RenameDatasetLabelsDetails.
        :type: oci.data_labeling_service.models.LabelSet
        """
        self._target_label_set = target_label_set

    def __repr__(self):
        return formatted_flat_dict(self)

    def __eq__(self, other):
        if other is None:
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        return not self == other



# coding: utf-8
# Copyright (c) 2016, 2022, Oracle and/or its affiliates.  All rights reserved.
# This software is dual-licensed to you under the Universal Permissive License (UPL) 1.0 as shown at https://oss.oracle.com/licenses/upl or Apache License 2.0 as shown at http://www.apache.org/licenses/LICENSE-2.0. You may choose either license.


from oci.util import formatted_flat_dict, NONE_SENTINEL, value_allowed_none_or_none_sentinel  # noqa: F401
from oci.decorators import init_model_state_from_kwargs


@init_model_state_from_kwargs
class CertificateSubject(object):
    """
    The subject of the certificate, which is a distinguished name that identifies the entity that owns the public key in the certificate.
    """

    def __init__(self, **kwargs):
        """
        Initializes a new CertificateSubject object with values from keyword arguments.
        The following keyword arguments are supported (corresponding to the getters/setters of this class):

        :param common_name:
            The value to assign to the common_name property of this CertificateSubject.
        :type common_name: str

        :param country:
            The value to assign to the country property of this CertificateSubject.
        :type country: str

        :param domain_component:
            The value to assign to the domain_component property of this CertificateSubject.
        :type domain_component: str

        :param distinguished_name_qualifier:
            The value to assign to the distinguished_name_qualifier property of this CertificateSubject.
        :type distinguished_name_qualifier: str

        :param generation_qualifier:
            The value to assign to the generation_qualifier property of this CertificateSubject.
        :type generation_qualifier: str

        :param given_name:
            The value to assign to the given_name property of this CertificateSubject.
        :type given_name: str

        :param initials:
            The value to assign to the initials property of this CertificateSubject.
        :type initials: str

        :param locality_name:
            The value to assign to the locality_name property of this CertificateSubject.
        :type locality_name: str

        :param organization:
            The value to assign to the organization property of this CertificateSubject.
        :type organization: str

        :param organizational_unit:
            The value to assign to the organizational_unit property of this CertificateSubject.
        :type organizational_unit: str

        :param pseudonym:
            The value to assign to the pseudonym property of this CertificateSubject.
        :type pseudonym: str

        :param serial_number:
            The value to assign to the serial_number property of this CertificateSubject.
        :type serial_number: str

        :param state_or_province_name:
            The value to assign to the state_or_province_name property of this CertificateSubject.
        :type state_or_province_name: str

        :param street:
            The value to assign to the street property of this CertificateSubject.
        :type street: str

        :param surname:
            The value to assign to the surname property of this CertificateSubject.
        :type surname: str

        :param title:
            The value to assign to the title property of this CertificateSubject.
        :type title: str

        :param user_id:
            The value to assign to the user_id property of this CertificateSubject.
        :type user_id: str

        """
        self.swagger_types = {
            'common_name': 'str',
            'country': 'str',
            'domain_component': 'str',
            'distinguished_name_qualifier': 'str',
            'generation_qualifier': 'str',
            'given_name': 'str',
            'initials': 'str',
            'locality_name': 'str',
            'organization': 'str',
            'organizational_unit': 'str',
            'pseudonym': 'str',
            'serial_number': 'str',
            'state_or_province_name': 'str',
            'street': 'str',
            'surname': 'str',
            'title': 'str',
            'user_id': 'str'
        }

        self.attribute_map = {
            'common_name': 'commonName',
            'country': 'country',
            'domain_component': 'domainComponent',
            'distinguished_name_qualifier': 'distinguishedNameQualifier',
            'generation_qualifier': 'generationQualifier',
            'given_name': 'givenName',
            'initials': 'initials',
            'locality_name': 'localityName',
            'organization': 'organization',
            'organizational_unit': 'organizationalUnit',
            'pseudonym': 'pseudonym',
            'serial_number': 'serialNumber',
            'state_or_province_name': 'stateOrProvinceName',
            'street': 'street',
            'surname': 'surname',
            'title': 'title',
            'user_id': 'userId'
        }

        self._common_name = None
        self._country = None
        self._domain_component = None
        self._distinguished_name_qualifier = None
        self._generation_qualifier = None
        self._given_name = None
        self._initials = None
        self._locality_name = None
        self._organization = None
        self._organizational_unit = None
        self._pseudonym = None
        self._serial_number = None
        self._state_or_province_name = None
        self._street = None
        self._surname = None
        self._title = None
        self._user_id = None

    @property
    def common_name(self):
        """
        **[Required]** Gets the common_name of this CertificateSubject.
        Common name or fully-qualified domain name (RDN CN).


        :return: The common_name of this CertificateSubject.
        :rtype: str
        """
        return self._common_name

    @common_name.setter
    def common_name(self, common_name):
        """
        Sets the common_name of this CertificateSubject.
        Common name or fully-qualified domain name (RDN CN).


        :param common_name: The common_name of this CertificateSubject.
        :type: str
        """
        self._common_name = common_name

    @property
    def country(self):
        """
        Gets the country of this CertificateSubject.
        Country name (RDN C).


        :return: The country of this CertificateSubject.
        :rtype: str
        """
        return self._country

    @country.setter
    def country(self, country):
        """
        Sets the country of this CertificateSubject.
        Country name (RDN C).


        :param country: The country of this CertificateSubject.
        :type: str
        """
        self._country = country

    @property
    def domain_component(self):
        """
        Gets the domain_component of this CertificateSubject.
        Domain component (RDN DC).


        :return: The domain_component of this CertificateSubject.
        :rtype: str
        """
        return self._domain_component

    @domain_component.setter
    def domain_component(self, domain_component):
        """
        Sets the domain_component of this CertificateSubject.
        Domain component (RDN DC).


        :param domain_component: The domain_component of this CertificateSubject.
        :type: str
        """
        self._domain_component = domain_component

    @property
    def distinguished_name_qualifier(self):
        """
        Gets the distinguished_name_qualifier of this CertificateSubject.
        Distinguished name qualifier(RDN DNQ).


        :return: The distinguished_name_qualifier of this CertificateSubject.
        :rtype: str
        """
        return self._distinguished_name_qualifier

    @distinguished_name_qualifier.setter
    def distinguished_name_qualifier(self, distinguished_name_qualifier):
        """
        Sets the distinguished_name_qualifier of this CertificateSubject.
        Distinguished name qualifier(RDN DNQ).


        :param distinguished_name_qualifier: The distinguished_name_qualifier of this CertificateSubject.
        :type: str
        """
        self._distinguished_name_qualifier = distinguished_name_qualifier

    @property
    def generation_qualifier(self):
        """
        Gets the generation_qualifier of this CertificateSubject.
        Personal generational qualifier (for example, Sr., Jr. 3rd, or IV).


        :return: The generation_qualifier of this CertificateSubject.
        :rtype: str
        """
        return self._generation_qualifier

    @generation_qualifier.setter
    def generation_qualifier(self, generation_qualifier):
        """
        Sets the generation_qualifier of this CertificateSubject.
        Personal generational qualifier (for example, Sr., Jr. 3rd, or IV).


        :param generation_qualifier: The generation_qualifier of this CertificateSubject.
        :type: str
        """
        self._generation_qualifier = generation_qualifier

    @property
    def given_name(self):
        """
        Gets the given_name of this CertificateSubject.
        Personal given name (RDN G or GN).


        :return: The given_name of this CertificateSubject.
        :rtype: str
        """
        return self._given_name

    @given_name.setter
    def given_name(self, given_name):
        """
        Sets the given_name of this CertificateSubject.
        Personal given name (RDN G or GN).


        :param given_name: The given_name of this CertificateSubject.
        :type: str
        """
        self._given_name = given_name

    @property
    def initials(self):
        """
        Gets the initials of this CertificateSubject.
        Personal initials.


        :return: The initials of this CertificateSubject.
        :rtype: str
        """
        return self._initials

    @initials.setter
    def initials(self, initials):
        """
        Sets the initials of this CertificateSubject.
        Personal initials.


        :param initials: The initials of this CertificateSubject.
        :type: str
        """
        self._initials = initials

    @property
    def locality_name(self):
        """
        Gets the locality_name of this CertificateSubject.
        Locality (RDN L).


        :return: The locality_name of this CertificateSubject.
        :rtype: str
        """
        return self._locality_name

    @locality_name.setter
    def locality_name(self, locality_name):
        """
        Sets the locality_name of this CertificateSubject.
        Locality (RDN L).


        :param locality_name: The locality_name of this CertificateSubject.
        :type: str
        """
        self._locality_name = locality_name

    @property
    def organization(self):
        """
        Gets the organization of this CertificateSubject.
        Organization (RDN O).


        :return: The organization of this CertificateSubject.
        :rtype: str
        """
        return self._organization

    @organization.setter
    def organization(self, organization):
        """
        Sets the organization of this CertificateSubject.
        Organization (RDN O).


        :param organization: The organization of this CertificateSubject.
        :type: str
        """
        self._organization = organization

    @property
    def organizational_unit(self):
        """
        Gets the organizational_unit of this CertificateSubject.
        Organizational unit (RDN OU).


        :return: The organizational_unit of this CertificateSubject.
        :rtype: str
        """
        return self._organizational_unit

    @organizational_unit.setter
    def organizational_unit(self, organizational_unit):
        """
        Sets the organizational_unit of this CertificateSubject.
        Organizational unit (RDN OU).


        :param organizational_unit: The organizational_unit of this CertificateSubject.
        :type: str
        """
        self._organizational_unit = organizational_unit

    @property
    def pseudonym(self):
        """
        Gets the pseudonym of this CertificateSubject.
        Subject pseudonym.


        :return: The pseudonym of this CertificateSubject.
        :rtype: str
        """
        return self._pseudonym

    @pseudonym.setter
    def pseudonym(self, pseudonym):
        """
        Sets the pseudonym of this CertificateSubject.
        Subject pseudonym.


        :param pseudonym: The pseudonym of this CertificateSubject.
        :type: str
        """
        self._pseudonym = pseudonym

    @property
    def serial_number(self):
        """
        Gets the serial_number of this CertificateSubject.
        Unique subject identifier, which is not the same as the certificate serial number (RDN SERIALNUMBER).


        :return: The serial_number of this CertificateSubject.
        :rtype: str
        """
        return self._serial_number

    @serial_number.setter
    def serial_number(self, serial_number):
        """
        Sets the serial_number of this CertificateSubject.
        Unique subject identifier, which is not the same as the certificate serial number (RDN SERIALNUMBER).


        :param serial_number: The serial_number of this CertificateSubject.
        :type: str
        """
        self._serial_number = serial_number

    @property
    def state_or_province_name(self):
        """
        Gets the state_or_province_name of this CertificateSubject.
        State or province name (RDN ST or S).


        :return: The state_or_province_name of this CertificateSubject.
        :rtype: str
        """
        return self._state_or_province_name

    @state_or_province_name.setter
    def state_or_province_name(self, state_or_province_name):
        """
        Sets the state_or_province_name of this CertificateSubject.
        State or province name (RDN ST or S).


        :param state_or_province_name: The state_or_province_name of this CertificateSubject.
        :type: str
        """
        self._state_or_province_name = state_or_province_name

    @property
    def street(self):
        """
        Gets the street of this CertificateSubject.
        Street address (RDN STREET).


        :return: The street of this CertificateSubject.
        :rtype: str
        """
        return self._street

    @street.setter
    def street(self, street):
        """
        Sets the street of this CertificateSubject.
        Street address (RDN STREET).


        :param street: The street of this CertificateSubject.
        :type: str
        """
        self._street = street

    @property
    def surname(self):
        """
        Gets the surname of this CertificateSubject.
        Personal surname (RDN SN).


        :return: The surname of this CertificateSubject.
        :rtype: str
        """
        return self._surname

    @surname.setter
    def surname(self, surname):
        """
        Sets the surname of this CertificateSubject.
        Personal surname (RDN SN).


        :param surname: The surname of this CertificateSubject.
        :type: str
        """
        self._surname = surname

    @property
    def title(self):
        """
        Gets the title of this CertificateSubject.
        Title (RDN T or TITLE).


        :return: The title of this CertificateSubject.
        :rtype: str
        """
        return self._title

    @title.setter
    def title(self, title):
        """
        Sets the title of this CertificateSubject.
        Title (RDN T or TITLE).


        :param title: The title of this CertificateSubject.
        :type: str
        """
        self._title = title

    @property
    def user_id(self):
        """
        Gets the user_id of this CertificateSubject.
        User ID (RDN UID).


        :return: The user_id of this CertificateSubject.
        :rtype: str
        """
        return self._user_id

    @user_id.setter
    def user_id(self, user_id):
        """
        Sets the user_id of this CertificateSubject.
        User ID (RDN UID).


        :param user_id: The user_id of this CertificateSubject.
        :type: str
        """
        self._user_id = user_id

    def __repr__(self):
        return formatted_flat_dict(self)

    def __eq__(self, other):
        if other is None:
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        return not self == other



# coding: utf-8
# Copyright (c) 2016, 2022, Oracle and/or its affiliates.  All rights reserved.
# This software is dual-licensed to you under the Universal Permissive License (UPL) 1.0 as shown at https://oss.oracle.com/licenses/upl or Apache License 2.0 as shown at http://www.apache.org/licenses/LICENSE-2.0. You may choose either license.


from oci.util import formatted_flat_dict, NONE_SENTINEL, value_allowed_none_or_none_sentinel  # noqa: F401
from oci.decorators import init_model_state_from_kwargs


@init_model_state_from_kwargs
class TranscriptionJob(object):
    """
    Description of Transcription Job.
    """

    #: A constant which can be used with the additional_transcription_formats property of a TranscriptionJob.
    #: This constant has a value of "SRT"
    ADDITIONAL_TRANSCRIPTION_FORMATS_SRT = "SRT"

    #: A constant which can be used with the lifecycle_state property of a TranscriptionJob.
    #: This constant has a value of "ACCEPTED"
    LIFECYCLE_STATE_ACCEPTED = "ACCEPTED"

    #: A constant which can be used with the lifecycle_state property of a TranscriptionJob.
    #: This constant has a value of "IN_PROGRESS"
    LIFECYCLE_STATE_IN_PROGRESS = "IN_PROGRESS"

    #: A constant which can be used with the lifecycle_state property of a TranscriptionJob.
    #: This constant has a value of "SUCCEEDED"
    LIFECYCLE_STATE_SUCCEEDED = "SUCCEEDED"

    #: A constant which can be used with the lifecycle_state property of a TranscriptionJob.
    #: This constant has a value of "FAILED"
    LIFECYCLE_STATE_FAILED = "FAILED"

    #: A constant which can be used with the lifecycle_state property of a TranscriptionJob.
    #: This constant has a value of "CANCELING"
    LIFECYCLE_STATE_CANCELING = "CANCELING"

    #: A constant which can be used with the lifecycle_state property of a TranscriptionJob.
    #: This constant has a value of "CANCELED"
    LIFECYCLE_STATE_CANCELED = "CANCELED"

    def __init__(self, **kwargs):
        """
        Initializes a new TranscriptionJob object with values from keyword arguments.
        The following keyword arguments are supported (corresponding to the getters/setters of this class):

        :param id:
            The value to assign to the id property of this TranscriptionJob.
        :type id: str

        :param display_name:
            The value to assign to the display_name property of this TranscriptionJob.
        :type display_name: str

        :param compartment_id:
            The value to assign to the compartment_id property of this TranscriptionJob.
        :type compartment_id: str

        :param description:
            The value to assign to the description property of this TranscriptionJob.
        :type description: str

        :param model_details:
            The value to assign to the model_details property of this TranscriptionJob.
        :type model_details: oci.ai_speech.models.TranscriptionModelDetails

        :param normalization:
            The value to assign to the normalization property of this TranscriptionJob.
        :type normalization: oci.ai_speech.models.TranscriptionNormalization

        :param time_accepted:
            The value to assign to the time_accepted property of this TranscriptionJob.
        :type time_accepted: datetime

        :param time_started:
            The value to assign to the time_started property of this TranscriptionJob.
        :type time_started: datetime

        :param time_finished:
            The value to assign to the time_finished property of this TranscriptionJob.
        :type time_finished: datetime

        :param total_tasks:
            The value to assign to the total_tasks property of this TranscriptionJob.
        :type total_tasks: int

        :param outstanding_tasks:
            The value to assign to the outstanding_tasks property of this TranscriptionJob.
        :type outstanding_tasks: int

        :param successful_tasks:
            The value to assign to the successful_tasks property of this TranscriptionJob.
        :type successful_tasks: int

        :param ttl_in_days:
            The value to assign to the ttl_in_days property of this TranscriptionJob.
        :type ttl_in_days: int

        :param percent_complete:
            The value to assign to the percent_complete property of this TranscriptionJob.
        :type percent_complete: int

        :param input_location:
            The value to assign to the input_location property of this TranscriptionJob.
        :type input_location: oci.ai_speech.models.InputLocation

        :param output_location:
            The value to assign to the output_location property of this TranscriptionJob.
        :type output_location: oci.ai_speech.models.OutputLocation

        :param created_by:
            The value to assign to the created_by property of this TranscriptionJob.
        :type created_by: str

        :param additional_transcription_formats:
            The value to assign to the additional_transcription_formats property of this TranscriptionJob.
            Allowed values for items in this list are: "SRT", 'UNKNOWN_ENUM_VALUE'.
            Any unrecognized values returned by a service will be mapped to 'UNKNOWN_ENUM_VALUE'.
        :type additional_transcription_formats: list[str]

        :param lifecycle_state:
            The value to assign to the lifecycle_state property of this TranscriptionJob.
            Allowed values for this property are: "ACCEPTED", "IN_PROGRESS", "SUCCEEDED", "FAILED", "CANCELING", "CANCELED", 'UNKNOWN_ENUM_VALUE'.
            Any unrecognized values returned by a service will be mapped to 'UNKNOWN_ENUM_VALUE'.
        :type lifecycle_state: str

        :param lifecycle_details:
            The value to assign to the lifecycle_details property of this TranscriptionJob.
        :type lifecycle_details: str

        :param freeform_tags:
            The value to assign to the freeform_tags property of this TranscriptionJob.
        :type freeform_tags: dict(str, str)

        :param defined_tags:
            The value to assign to the defined_tags property of this TranscriptionJob.
        :type defined_tags: dict(str, dict(str, object))

        :param system_tags:
            The value to assign to the system_tags property of this TranscriptionJob.
        :type system_tags: dict(str, dict(str, object))

        """
        self.swagger_types = {
            'id': 'str',
            'display_name': 'str',
            'compartment_id': 'str',
            'description': 'str',
            'model_details': 'TranscriptionModelDetails',
            'normalization': 'TranscriptionNormalization',
            'time_accepted': 'datetime',
            'time_started': 'datetime',
            'time_finished': 'datetime',
            'total_tasks': 'int',
            'outstanding_tasks': 'int',
            'successful_tasks': 'int',
            'ttl_in_days': 'int',
            'percent_complete': 'int',
            'input_location': 'InputLocation',
            'output_location': 'OutputLocation',
            'created_by': 'str',
            'additional_transcription_formats': 'list[str]',
            'lifecycle_state': 'str',
            'lifecycle_details': 'str',
            'freeform_tags': 'dict(str, str)',
            'defined_tags': 'dict(str, dict(str, object))',
            'system_tags': 'dict(str, dict(str, object))'
        }

        self.attribute_map = {
            'id': 'id',
            'display_name': 'displayName',
            'compartment_id': 'compartmentId',
            'description': 'description',
            'model_details': 'modelDetails',
            'normalization': 'normalization',
            'time_accepted': 'timeAccepted',
            'time_started': 'timeStarted',
            'time_finished': 'timeFinished',
            'total_tasks': 'totalTasks',
            'outstanding_tasks': 'outstandingTasks',
            'successful_tasks': 'successfulTasks',
            'ttl_in_days': 'ttlInDays',
            'percent_complete': 'percentComplete',
            'input_location': 'inputLocation',
            'output_location': 'outputLocation',
            'created_by': 'createdBy',
            'additional_transcription_formats': 'additionalTranscriptionFormats',
            'lifecycle_state': 'lifecycleState',
            'lifecycle_details': 'lifecycleDetails',
            'freeform_tags': 'freeformTags',
            'defined_tags': 'definedTags',
            'system_tags': 'systemTags'
        }

        self._id = None
        self._display_name = None
        self._compartment_id = None
        self._description = None
        self._model_details = None
        self._normalization = None
        self._time_accepted = None
        self._time_started = None
        self._time_finished = None
        self._total_tasks = None
        self._outstanding_tasks = None
        self._successful_tasks = None
        self._ttl_in_days = None
        self._percent_complete = None
        self._input_location = None
        self._output_location = None
        self._created_by = None
        self._additional_transcription_formats = None
        self._lifecycle_state = None
        self._lifecycle_details = None
        self._freeform_tags = None
        self._defined_tags = None
        self._system_tags = None

    @property
    def id(self):
        """
        **[Required]** Gets the id of this TranscriptionJob.
        The `OCID`__ of the job.

        __ https://docs.cloud.oracle.com/iaas/Content/General/Concepts/identifiers.htm


        :return: The id of this TranscriptionJob.
        :rtype: str
        """
        return self._id

    @id.setter
    def id(self, id):
        """
        Sets the id of this TranscriptionJob.
        The `OCID`__ of the job.

        __ https://docs.cloud.oracle.com/iaas/Content/General/Concepts/identifiers.htm


        :param id: The id of this TranscriptionJob.
        :type: str
        """
        self._id = id

    @property
    def display_name(self):
        """
        Gets the display_name of this TranscriptionJob.
        A user-friendly display name for the job.


        :return: The display_name of this TranscriptionJob.
        :rtype: str
        """
        return self._display_name

    @display_name.setter
    def display_name(self, display_name):
        """
        Sets the display_name of this TranscriptionJob.
        A user-friendly display name for the job.


        :param display_name: The display_name of this TranscriptionJob.
        :type: str
        """
        self._display_name = display_name

    @property
    def compartment_id(self):
        """
        **[Required]** Gets the compartment_id of this TranscriptionJob.
        The `OCID`__ of the compartment where you want to create the job.

        __ https://docs.cloud.oracle.com/iaas/Content/General/Concepts/identifiers.htm


        :return: The compartment_id of this TranscriptionJob.
        :rtype: str
        """
        return self._compartment_id

    @compartment_id.setter
    def compartment_id(self, compartment_id):
        """
        Sets the compartment_id of this TranscriptionJob.
        The `OCID`__ of the compartment where you want to create the job.

        __ https://docs.cloud.oracle.com/iaas/Content/General/Concepts/identifiers.htm


        :param compartment_id: The compartment_id of this TranscriptionJob.
        :type: str
        """
        self._compartment_id = compartment_id

    @property
    def description(self):
        """
        Gets the description of this TranscriptionJob.
        A short description of the job.


        :return: The description of this TranscriptionJob.
        :rtype: str
        """
        return self._description

    @description.setter
    def description(self, description):
        """
        Sets the description of this TranscriptionJob.
        A short description of the job.


        :param description: The description of this TranscriptionJob.
        :type: str
        """
        self._description = description

    @property
    def model_details(self):
        """
        **[Required]** Gets the model_details of this TranscriptionJob.

        :return: The model_details of this TranscriptionJob.
        :rtype: oci.ai_speech.models.TranscriptionModelDetails
        """
        return self._model_details

    @model_details.setter
    def model_details(self, model_details):
        """
        Sets the model_details of this TranscriptionJob.

        :param model_details: The model_details of this TranscriptionJob.
        :type: oci.ai_speech.models.TranscriptionModelDetails
        """
        self._model_details = model_details

    @property
    def normalization(self):
        """
        Gets the normalization of this TranscriptionJob.

        :return: The normalization of this TranscriptionJob.
        :rtype: oci.ai_speech.models.TranscriptionNormalization
        """
        return self._normalization

    @normalization.setter
    def normalization(self, normalization):
        """
        Sets the normalization of this TranscriptionJob.

        :param normalization: The normalization of this TranscriptionJob.
        :type: oci.ai_speech.models.TranscriptionNormalization
        """
        self._normalization = normalization

    @property
    def time_accepted(self):
        """
        Gets the time_accepted of this TranscriptionJob.
        Job accepted time.


        :return: The time_accepted of this TranscriptionJob.
        :rtype: datetime
        """
        return self._time_accepted

    @time_accepted.setter
    def time_accepted(self, time_accepted):
        """
        Sets the time_accepted of this TranscriptionJob.
        Job accepted time.


        :param time_accepted: The time_accepted of this TranscriptionJob.
        :type: datetime
        """
        self._time_accepted = time_accepted

    @property
    def time_started(self):
        """
        Gets the time_started of this TranscriptionJob.
        Job started time.


        :return: The time_started of this TranscriptionJob.
        :rtype: datetime
        """
        return self._time_started

    @time_started.setter
    def time_started(self, time_started):
        """
        Sets the time_started of this TranscriptionJob.
        Job started time.


        :param time_started: The time_started of this TranscriptionJob.
        :type: datetime
        """
        self._time_started = time_started

    @property
    def time_finished(self):
        """
        Gets the time_finished of this TranscriptionJob.
        Job finished time.


        :return: The time_finished of this TranscriptionJob.
        :rtype: datetime
        """
        return self._time_finished

    @time_finished.setter
    def time_finished(self, time_finished):
        """
        Sets the time_finished of this TranscriptionJob.
        Job finished time.


        :param time_finished: The time_finished of this TranscriptionJob.
        :type: datetime
        """
        self._time_finished = time_finished

    @property
    def total_tasks(self):
        """
        Gets the total_tasks of this TranscriptionJob.
        Total tasks in a job.


        :return: The total_tasks of this TranscriptionJob.
        :rtype: int
        """
        return self._total_tasks

    @total_tasks.setter
    def total_tasks(self, total_tasks):
        """
        Sets the total_tasks of this TranscriptionJob.
        Total tasks in a job.


        :param total_tasks: The total_tasks of this TranscriptionJob.
        :type: int
        """
        self._total_tasks = total_tasks

    @property
    def outstanding_tasks(self):
        """
        Gets the outstanding_tasks of this TranscriptionJob.
        Total outstanding tasks in a job.


        :return: The outstanding_tasks of this TranscriptionJob.
        :rtype: int
        """
        return self._outstanding_tasks

    @outstanding_tasks.setter
    def outstanding_tasks(self, outstanding_tasks):
        """
        Sets the outstanding_tasks of this TranscriptionJob.
        Total outstanding tasks in a job.


        :param outstanding_tasks: The outstanding_tasks of this TranscriptionJob.
        :type: int
        """
        self._outstanding_tasks = outstanding_tasks

    @property
    def successful_tasks(self):
        """
        Gets the successful_tasks of this TranscriptionJob.
        Total successful tasks in a job.


        :return: The successful_tasks of this TranscriptionJob.
        :rtype: int
        """
        return self._successful_tasks

    @successful_tasks.setter
    def successful_tasks(self, successful_tasks):
        """
        Sets the successful_tasks of this TranscriptionJob.
        Total successful tasks in a job.


        :param successful_tasks: The successful_tasks of this TranscriptionJob.
        :type: int
        """
        self._successful_tasks = successful_tasks

    @property
    def ttl_in_days(self):
        """
        Gets the ttl_in_days of this TranscriptionJob.
        Time to live duration in days for Job. Job will be available till max 90 days.


        :return: The ttl_in_days of this TranscriptionJob.
        :rtype: int
        """
        return self._ttl_in_days

    @ttl_in_days.setter
    def ttl_in_days(self, ttl_in_days):
        """
        Sets the ttl_in_days of this TranscriptionJob.
        Time to live duration in days for Job. Job will be available till max 90 days.


        :param ttl_in_days: The ttl_in_days of this TranscriptionJob.
        :type: int
        """
        self._ttl_in_days = ttl_in_days

    @property
    def percent_complete(self):
        """
        Gets the percent_complete of this TranscriptionJob.
        How much progress the operation has made, vs the total amount of work that must be performed.


        :return: The percent_complete of this TranscriptionJob.
        :rtype: int
        """
        return self._percent_complete

    @percent_complete.setter
    def percent_complete(self, percent_complete):
        """
        Sets the percent_complete of this TranscriptionJob.
        How much progress the operation has made, vs the total amount of work that must be performed.


        :param percent_complete: The percent_complete of this TranscriptionJob.
        :type: int
        """
        self._percent_complete = percent_complete

    @property
    def input_location(self):
        """
        **[Required]** Gets the input_location of this TranscriptionJob.

        :return: The input_location of this TranscriptionJob.
        :rtype: oci.ai_speech.models.InputLocation
        """
        return self._input_location

    @input_location.setter
    def input_location(self, input_location):
        """
        Sets the input_location of this TranscriptionJob.

        :param input_location: The input_location of this TranscriptionJob.
        :type: oci.ai_speech.models.InputLocation
        """
        self._input_location = input_location

    @property
    def output_location(self):
        """
        **[Required]** Gets the output_location of this TranscriptionJob.

        :return: The output_location of this TranscriptionJob.
        :rtype: oci.ai_speech.models.OutputLocation
        """
        return self._output_location

    @output_location.setter
    def output_location(self, output_location):
        """
        Sets the output_location of this TranscriptionJob.

        :param output_location: The output_location of this TranscriptionJob.
        :type: oci.ai_speech.models.OutputLocation
        """
        self._output_location = output_location

    @property
    def created_by(self):
        """
        Gets the created_by of this TranscriptionJob.
        The `OCID`__ of the user who created the job.

        __ https://docs.cloud.oracle.com/iaas/Content/General/Concepts/identifiers.htm


        :return: The created_by of this TranscriptionJob.
        :rtype: str
        """
        return self._created_by

    @created_by.setter
    def created_by(self, created_by):
        """
        Sets the created_by of this TranscriptionJob.
        The `OCID`__ of the user who created the job.

        __ https://docs.cloud.oracle.com/iaas/Content/General/Concepts/identifiers.htm


        :param created_by: The created_by of this TranscriptionJob.
        :type: str
        """
        self._created_by = created_by

    @property
    def additional_transcription_formats(self):
        """
        Gets the additional_transcription_formats of this TranscriptionJob.
        Transcription format. JSON format will always be provided in addition to any formats in this list.

        Allowed values for items in this list are: "SRT", 'UNKNOWN_ENUM_VALUE'.
        Any unrecognized values returned by a service will be mapped to 'UNKNOWN_ENUM_VALUE'.


        :return: The additional_transcription_formats of this TranscriptionJob.
        :rtype: list[str]
        """
        return self._additional_transcription_formats

    @additional_transcription_formats.setter
    def additional_transcription_formats(self, additional_transcription_formats):
        """
        Sets the additional_transcription_formats of this TranscriptionJob.
        Transcription format. JSON format will always be provided in addition to any formats in this list.


        :param additional_transcription_formats: The additional_transcription_formats of this TranscriptionJob.
        :type: list[str]
        """
        allowed_values = ["SRT"]
        if additional_transcription_formats:
            additional_transcription_formats[:] = ['UNKNOWN_ENUM_VALUE' if not value_allowed_none_or_none_sentinel(x, allowed_values) else x for x in additional_transcription_formats]
        self._additional_transcription_formats = additional_transcription_formats

    @property
    def lifecycle_state(self):
        """
        Gets the lifecycle_state of this TranscriptionJob.
        The current state of the Job.

        Allowed values for this property are: "ACCEPTED", "IN_PROGRESS", "SUCCEEDED", "FAILED", "CANCELING", "CANCELED", 'UNKNOWN_ENUM_VALUE'.
        Any unrecognized values returned by a service will be mapped to 'UNKNOWN_ENUM_VALUE'.


        :return: The lifecycle_state of this TranscriptionJob.
        :rtype: str
        """
        return self._lifecycle_state

    @lifecycle_state.setter
    def lifecycle_state(self, lifecycle_state):
        """
        Sets the lifecycle_state of this TranscriptionJob.
        The current state of the Job.


        :param lifecycle_state: The lifecycle_state of this TranscriptionJob.
        :type: str
        """
        allowed_values = ["ACCEPTED", "IN_PROGRESS", "SUCCEEDED", "FAILED", "CANCELING", "CANCELED"]
        if not value_allowed_none_or_none_sentinel(lifecycle_state, allowed_values):
            lifecycle_state = 'UNKNOWN_ENUM_VALUE'
        self._lifecycle_state = lifecycle_state

    @property
    def lifecycle_details(self):
        """
        Gets the lifecycle_details of this TranscriptionJob.
        A message describing the current state in more detail. For example, can be used to provide actionable information for a resource in Failed state.


        :return: The lifecycle_details of this TranscriptionJob.
        :rtype: str
        """
        return self._lifecycle_details

    @lifecycle_details.setter
    def lifecycle_details(self, lifecycle_details):
        """
        Sets the lifecycle_details of this TranscriptionJob.
        A message describing the current state in more detail. For example, can be used to provide actionable information for a resource in Failed state.


        :param lifecycle_details: The lifecycle_details of this TranscriptionJob.
        :type: str
        """
        self._lifecycle_details = lifecycle_details

    @property
    def freeform_tags(self):
        """
        Gets the freeform_tags of this TranscriptionJob.
        Simple key-value pair that is applied without any predefined name, type or scope. Exists for cross-compatibility only.
        Example: `{\"bar-key\": \"value\"}`


        :return: The freeform_tags of this TranscriptionJob.
        :rtype: dict(str, str)
        """
        return self._freeform_tags

    @freeform_tags.setter
    def freeform_tags(self, freeform_tags):
        """
        Sets the freeform_tags of this TranscriptionJob.
        Simple key-value pair that is applied without any predefined name, type or scope. Exists for cross-compatibility only.
        Example: `{\"bar-key\": \"value\"}`


        :param freeform_tags: The freeform_tags of this TranscriptionJob.
        :type: dict(str, str)
        """
        self._freeform_tags = freeform_tags

    @property
    def defined_tags(self):
        """
        Gets the defined_tags of this TranscriptionJob.
        Defined tags for this resource. Each key is predefined and scoped to a namespace.
        Example: `{\"foo-namespace\": {\"bar-key\": \"value\"}}`


        :return: The defined_tags of this TranscriptionJob.
        :rtype: dict(str, dict(str, object))
        """
        return self._defined_tags

    @defined_tags.setter
    def defined_tags(self, defined_tags):
        """
        Sets the defined_tags of this TranscriptionJob.
        Defined tags for this resource. Each key is predefined and scoped to a namespace.
        Example: `{\"foo-namespace\": {\"bar-key\": \"value\"}}`


        :param defined_tags: The defined_tags of this TranscriptionJob.
        :type: dict(str, dict(str, object))
        """
        self._defined_tags = defined_tags

    @property
    def system_tags(self):
        """
        Gets the system_tags of this TranscriptionJob.
        Usage of system tag keys. These predefined keys are scoped to namespaces.
        Example: `{\"orcl-cloud\": {\"free-tier-retained\": \"true\"}}`


        :return: The system_tags of this TranscriptionJob.
        :rtype: dict(str, dict(str, object))
        """
        return self._system_tags

    @system_tags.setter
    def system_tags(self, system_tags):
        """
        Sets the system_tags of this TranscriptionJob.
        Usage of system tag keys. These predefined keys are scoped to namespaces.
        Example: `{\"orcl-cloud\": {\"free-tier-retained\": \"true\"}}`


        :param system_tags: The system_tags of this TranscriptionJob.
        :type: dict(str, dict(str, object))
        """
        self._system_tags = system_tags

    def __repr__(self):
        return formatted_flat_dict(self)

    def __eq__(self, other):
        if other is None:
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        return not self == other



# coding: utf-8
# Copyright (c) 2016, 2022, Oracle and/or its affiliates.  All rights reserved.
# This software is dual-licensed to you under the Universal Permissive License (UPL) 1.0 as shown at https://oss.oracle.com/licenses/upl or Apache License 2.0 as shown at http://www.apache.org/licenses/LICENSE-2.0. You may choose either license.


from oci.util import formatted_flat_dict, NONE_SENTINEL, value_allowed_none_or_none_sentinel  # noqa: F401
from oci.decorators import init_model_state_from_kwargs


@init_model_state_from_kwargs
class CreateIngressGatewayMutualTransportLayerSecurityDetails(object):
    """
    Mutual TLS settings used when sending requests to virtual services within the mesh.
    """

    def __init__(self, **kwargs):
        """
        Initializes a new CreateIngressGatewayMutualTransportLayerSecurityDetails object with values from keyword arguments.
        The following keyword arguments are supported (corresponding to the getters/setters of this class):

        :param maximum_validity:
            The value to assign to the maximum_validity property of this CreateIngressGatewayMutualTransportLayerSecurityDetails.
        :type maximum_validity: int

        """
        self.swagger_types = {
            'maximum_validity': 'int'
        }

        self.attribute_map = {
            'maximum_validity': 'maximumValidity'
        }

        self._maximum_validity = None

    @property
    def maximum_validity(self):
        """
        Gets the maximum_validity of this CreateIngressGatewayMutualTransportLayerSecurityDetails.
        The number of days the mTLS certificate is valid.  This value should be less than the Maximum Validity Duration
        for Certificates (Days) setting on the Certificate Authority associated with this Mesh.  The certificate will
        be automatically renewed after 2/3 of the validity period, so a certificate with a maximum validity of 45 days
        will be renewed every 30 days.


        :return: The maximum_validity of this CreateIngressGatewayMutualTransportLayerSecurityDetails.
        :rtype: int
        """
        return self._maximum_validity

    @maximum_validity.setter
    def maximum_validity(self, maximum_validity):
        """
        Sets the maximum_validity of this CreateIngressGatewayMutualTransportLayerSecurityDetails.
        The number of days the mTLS certificate is valid.  This value should be less than the Maximum Validity Duration
        for Certificates (Days) setting on the Certificate Authority associated with this Mesh.  The certificate will
        be automatically renewed after 2/3 of the validity period, so a certificate with a maximum validity of 45 days
        will be renewed every 30 days.


        :param maximum_validity: The maximum_validity of this CreateIngressGatewayMutualTransportLayerSecurityDetails.
        :type: int
        """
        self._maximum_validity = maximum_validity

    def __repr__(self):
        return formatted_flat_dict(self)

    def __eq__(self, other):
        if other is None:
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        return not self == other



# coding: utf-8
# Copyright (c) 2016, 2022, Oracle and/or its affiliates.  All rights reserved.
# This software is dual-licensed to you under the Universal Permissive License (UPL) 1.0 as shown at https://oss.oracle.com/licenses/upl or Apache License 2.0 as shown at http://www.apache.org/licenses/LICENSE-2.0. You may choose either license.


from oci.util import formatted_flat_dict, NONE_SENTINEL, value_allowed_none_or_none_sentinel  # noqa: F401
from oci.decorators import init_model_state_from_kwargs


@init_model_state_from_kwargs
class SentimentDocumentResult(object):
    """
    The document response for sentiment detect call.
    """

    def __init__(self, **kwargs):
        """
        Initializes a new SentimentDocumentResult object with values from keyword arguments.
        The following keyword arguments are supported (corresponding to the getters/setters of this class):

        :param key:
            The value to assign to the key property of this SentimentDocumentResult.
        :type key: str

        :param document_sentiment:
            The value to assign to the document_sentiment property of this SentimentDocumentResult.
        :type document_sentiment: str

        :param document_scores:
            The value to assign to the document_scores property of this SentimentDocumentResult.
        :type document_scores: dict(str, float)

        :param aspects:
            The value to assign to the aspects property of this SentimentDocumentResult.
        :type aspects: list[oci.ai_language.models.SentimentAspect]

        :param sentences:
            The value to assign to the sentences property of this SentimentDocumentResult.
        :type sentences: list[oci.ai_language.models.SentimentSentence]

        :param language_code:
            The value to assign to the language_code property of this SentimentDocumentResult.
        :type language_code: str

        """
        self.swagger_types = {
            'key': 'str',
            'document_sentiment': 'str',
            'document_scores': 'dict(str, float)',
            'aspects': 'list[SentimentAspect]',
            'sentences': 'list[SentimentSentence]',
            'language_code': 'str'
        }

        self.attribute_map = {
            'key': 'key',
            'document_sentiment': 'documentSentiment',
            'document_scores': 'documentScores',
            'aspects': 'aspects',
            'sentences': 'sentences',
            'language_code': 'languageCode'
        }

        self._key = None
        self._document_sentiment = None
        self._document_scores = None
        self._aspects = None
        self._sentences = None
        self._language_code = None

    @property
    def key(self):
        """
        **[Required]** Gets the key of this SentimentDocumentResult.
        Document Unique Identifier.


        :return: The key of this SentimentDocumentResult.
        :rtype: str
        """
        return self._key

    @key.setter
    def key(self, key):
        """
        Sets the key of this SentimentDocumentResult.
        Document Unique Identifier.


        :param key: The key of this SentimentDocumentResult.
        :type: str
        """
        self._key = key

    @property
    def document_sentiment(self):
        """
        Gets the document_sentiment of this SentimentDocumentResult.
        Document level sentiment.


        :return: The document_sentiment of this SentimentDocumentResult.
        :rtype: str
        """
        return self._document_sentiment

    @document_sentiment.setter
    def document_sentiment(self, document_sentiment):
        """
        Sets the document_sentiment of this SentimentDocumentResult.
        Document level sentiment.


        :param document_sentiment: The document_sentiment of this SentimentDocumentResult.
        :type: str
        """
        self._document_sentiment = document_sentiment

    @property
    def document_scores(self):
        """
        Gets the document_scores of this SentimentDocumentResult.
        Scores for each sentiment.
        Example: {\"positive\": 1.0, \"negative\": 0.0}


        :return: The document_scores of this SentimentDocumentResult.
        :rtype: dict(str, float)
        """
        return self._document_scores

    @document_scores.setter
    def document_scores(self, document_scores):
        """
        Sets the document_scores of this SentimentDocumentResult.
        Scores for each sentiment.
        Example: {\"positive\": 1.0, \"negative\": 0.0}


        :param document_scores: The document_scores of this SentimentDocumentResult.
        :type: dict(str, float)
        """
        self._document_scores = document_scores

    @property
    def aspects(self):
        """
        **[Required]** Gets the aspects of this SentimentDocumentResult.
        List of detected aspects sentiment.


        :return: The aspects of this SentimentDocumentResult.
        :rtype: list[oci.ai_language.models.SentimentAspect]
        """
        return self._aspects

    @aspects.setter
    def aspects(self, aspects):
        """
        Sets the aspects of this SentimentDocumentResult.
        List of detected aspects sentiment.


        :param aspects: The aspects of this SentimentDocumentResult.
        :type: list[oci.ai_language.models.SentimentAspect]
        """
        self._aspects = aspects

    @property
    def sentences(self):
        """
        Gets the sentences of this SentimentDocumentResult.
        List of detected sentences sentiment.


        :return: The sentences of this SentimentDocumentResult.
        :rtype: list[oci.ai_language.models.SentimentSentence]
        """
        return self._sentences

    @sentences.setter
    def sentences(self, sentences):
        """
        Sets the sentences of this SentimentDocumentResult.
        List of detected sentences sentiment.


        :param sentences: The sentences of this SentimentDocumentResult.
        :type: list[oci.ai_language.models.SentimentSentence]
        """
        self._sentences = sentences

    @property
    def language_code(self):
        """
        **[Required]** Gets the language_code of this SentimentDocumentResult.
        Language code as per `ISO 639-1`__ standard.

        __ https://en.wikipedia.org/wiki/List_of_ISO_639-1_codes


        :return: The language_code of this SentimentDocumentResult.
        :rtype: str
        """
        return self._language_code

    @language_code.setter
    def language_code(self, language_code):
        """
        Sets the language_code of this SentimentDocumentResult.
        Language code as per `ISO 639-1`__ standard.

        __ https://en.wikipedia.org/wiki/List_of_ISO_639-1_codes


        :param language_code: The language_code of this SentimentDocumentResult.
        :type: str
        """
        self._language_code = language_code

    def __repr__(self):
        return formatted_flat_dict(self)

    def __eq__(self, other):
        if other is None:
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        return not self == other



# coding: utf-8
# Copyright (c) 2016, 2022, Oracle and/or its affiliates.  All rights reserved.
# This software is dual-licensed to you under the Universal Permissive License (UPL) 1.0 as shown at https://oss.oracle.com/licenses/upl or Apache License 2.0 as shown at http://www.apache.org/licenses/LICENSE-2.0. You may choose either license.


from oci.util import formatted_flat_dict, NONE_SENTINEL, value_allowed_none_or_none_sentinel  # noqa: F401
from oci.decorators import init_model_state_from_kwargs


@init_model_state_from_kwargs
class CreateCloudAutonomousVmClusterDetails(object):
    """
    Details for the create cloud Autonomous VM cluster operation.
    """

    #: A constant which can be used with the license_model property of a CreateCloudAutonomousVmClusterDetails.
    #: This constant has a value of "LICENSE_INCLUDED"
    LICENSE_MODEL_LICENSE_INCLUDED = "LICENSE_INCLUDED"

    #: A constant which can be used with the license_model property of a CreateCloudAutonomousVmClusterDetails.
    #: This constant has a value of "BRING_YOUR_OWN_LICENSE"
    LICENSE_MODEL_BRING_YOUR_OWN_LICENSE = "BRING_YOUR_OWN_LICENSE"

    def __init__(self, **kwargs):
        """
        Initializes a new CreateCloudAutonomousVmClusterDetails object with values from keyword arguments.
        The following keyword arguments are supported (corresponding to the getters/setters of this class):

        :param compartment_id:
            The value to assign to the compartment_id property of this CreateCloudAutonomousVmClusterDetails.
        :type compartment_id: str

        :param description:
            The value to assign to the description property of this CreateCloudAutonomousVmClusterDetails.
        :type description: str

        :param subnet_id:
            The value to assign to the subnet_id property of this CreateCloudAutonomousVmClusterDetails.
        :type subnet_id: str

        :param display_name:
            The value to assign to the display_name property of this CreateCloudAutonomousVmClusterDetails.
        :type display_name: str

        :param cloud_exadata_infrastructure_id:
            The value to assign to the cloud_exadata_infrastructure_id property of this CreateCloudAutonomousVmClusterDetails.
        :type cloud_exadata_infrastructure_id: str

        :param cluster_time_zone:
            The value to assign to the cluster_time_zone property of this CreateCloudAutonomousVmClusterDetails.
        :type cluster_time_zone: str

        :param license_model:
            The value to assign to the license_model property of this CreateCloudAutonomousVmClusterDetails.
            Allowed values for this property are: "LICENSE_INCLUDED", "BRING_YOUR_OWN_LICENSE"
        :type license_model: str

        :param nsg_ids:
            The value to assign to the nsg_ids property of this CreateCloudAutonomousVmClusterDetails.
        :type nsg_ids: list[str]

        :param freeform_tags:
            The value to assign to the freeform_tags property of this CreateCloudAutonomousVmClusterDetails.
        :type freeform_tags: dict(str, str)

        :param defined_tags:
            The value to assign to the defined_tags property of this CreateCloudAutonomousVmClusterDetails.
        :type defined_tags: dict(str, dict(str, object))

        """
        self.swagger_types = {
            'compartment_id': 'str',
            'description': 'str',
            'subnet_id': 'str',
            'display_name': 'str',
            'cloud_exadata_infrastructure_id': 'str',
            'cluster_time_zone': 'str',
            'license_model': 'str',
            'nsg_ids': 'list[str]',
            'freeform_tags': 'dict(str, str)',
            'defined_tags': 'dict(str, dict(str, object))'
        }

        self.attribute_map = {
            'compartment_id': 'compartmentId',
            'description': 'description',
            'subnet_id': 'subnetId',
            'display_name': 'displayName',
            'cloud_exadata_infrastructure_id': 'cloudExadataInfrastructureId',
            'cluster_time_zone': 'clusterTimeZone',
            'license_model': 'licenseModel',
            'nsg_ids': 'nsgIds',
            'freeform_tags': 'freeformTags',
            'defined_tags': 'definedTags'
        }

        self._compartment_id = None
        self._description = None
        self._subnet_id = None
        self._display_name = None
        self._cloud_exadata_infrastructure_id = None
        self._cluster_time_zone = None
        self._license_model = None
        self._nsg_ids = None
        self._freeform_tags = None
        self._defined_tags = None

    @property
    def compartment_id(self):
        """
        **[Required]** Gets the compartment_id of this CreateCloudAutonomousVmClusterDetails.
        The `OCID`__ of the compartment.

        __ https://docs.cloud.oracle.com/Content/General/Concepts/identifiers.htm


        :return: The compartment_id of this CreateCloudAutonomousVmClusterDetails.
        :rtype: str
        """
        return self._compartment_id

    @compartment_id.setter
    def compartment_id(self, compartment_id):
        """
        Sets the compartment_id of this CreateCloudAutonomousVmClusterDetails.
        The `OCID`__ of the compartment.

        __ https://docs.cloud.oracle.com/Content/General/Concepts/identifiers.htm


        :param compartment_id: The compartment_id of this CreateCloudAutonomousVmClusterDetails.
        :type: str
        """
        self._compartment_id = compartment_id

    @property
    def description(self):
        """
        Gets the description of this CreateCloudAutonomousVmClusterDetails.
        User defined description of the cloud Autonomous VM cluster.


        :return: The description of this CreateCloudAutonomousVmClusterDetails.
        :rtype: str
        """
        return self._description

    @description.setter
    def description(self, description):
        """
        Sets the description of this CreateCloudAutonomousVmClusterDetails.
        User defined description of the cloud Autonomous VM cluster.


        :param description: The description of this CreateCloudAutonomousVmClusterDetails.
        :type: str
        """
        self._description = description

    @property
    def subnet_id(self):
        """
        **[Required]** Gets the subnet_id of this CreateCloudAutonomousVmClusterDetails.
        The `OCID`__ of the subnet the cloud Autonomous VM Cluster is associated with.

        __ https://docs.cloud.oracle.com/Content/General/Concepts/identifiers.htm


        :return: The subnet_id of this CreateCloudAutonomousVmClusterDetails.
        :rtype: str
        """
        return self._subnet_id

    @subnet_id.setter
    def subnet_id(self, subnet_id):
        """
        Sets the subnet_id of this CreateCloudAutonomousVmClusterDetails.
        The `OCID`__ of the subnet the cloud Autonomous VM Cluster is associated with.

        __ https://docs.cloud.oracle.com/Content/General/Concepts/identifiers.htm


        :param subnet_id: The subnet_id of this CreateCloudAutonomousVmClusterDetails.
        :type: str
        """
        self._subnet_id = subnet_id

    @property
    def display_name(self):
        """
        **[Required]** Gets the display_name of this CreateCloudAutonomousVmClusterDetails.
        The user-friendly name for the cloud Autonomous VM cluster. The name does not need to be unique.


        :return: The display_name of this CreateCloudAutonomousVmClusterDetails.
        :rtype: str
        """
        return self._display_name

    @display_name.setter
    def display_name(self, display_name):
        """
        Sets the display_name of this CreateCloudAutonomousVmClusterDetails.
        The user-friendly name for the cloud Autonomous VM cluster. The name does not need to be unique.


        :param display_name: The display_name of this CreateCloudAutonomousVmClusterDetails.
        :type: str
        """
        self._display_name = display_name

    @property
    def cloud_exadata_infrastructure_id(self):
        """
        **[Required]** Gets the cloud_exadata_infrastructure_id of this CreateCloudAutonomousVmClusterDetails.
        The `OCID`__ of the cloud Exadata infrastructure.

        __ https://docs.cloud.oracle.com/Content/General/Concepts/identifiers.htm


        :return: The cloud_exadata_infrastructure_id of this CreateCloudAutonomousVmClusterDetails.
        :rtype: str
        """
        return self._cloud_exadata_infrastructure_id

    @cloud_exadata_infrastructure_id.setter
    def cloud_exadata_infrastructure_id(self, cloud_exadata_infrastructure_id):
        """
        Sets the cloud_exadata_infrastructure_id of this CreateCloudAutonomousVmClusterDetails.
        The `OCID`__ of the cloud Exadata infrastructure.

        __ https://docs.cloud.oracle.com/Content/General/Concepts/identifiers.htm


        :param cloud_exadata_infrastructure_id: The cloud_exadata_infrastructure_id of this CreateCloudAutonomousVmClusterDetails.
        :type: str
        """
        self._cloud_exadata_infrastructure_id = cloud_exadata_infrastructure_id

    @property
    def cluster_time_zone(self):
        """
        Gets the cluster_time_zone of this CreateCloudAutonomousVmClusterDetails.
        The time zone to use for the Cloud Autonomous VM cluster. For details, see `DB System Time Zones`__.

        __ https://docs.cloud.oracle.com/Content/Database/References/timezones.htm


        :return: The cluster_time_zone of this CreateCloudAutonomousVmClusterDetails.
        :rtype: str
        """
        return self._cluster_time_zone

    @cluster_time_zone.setter
    def cluster_time_zone(self, cluster_time_zone):
        """
        Sets the cluster_time_zone of this CreateCloudAutonomousVmClusterDetails.
        The time zone to use for the Cloud Autonomous VM cluster. For details, see `DB System Time Zones`__.

        __ https://docs.cloud.oracle.com/Content/Database/References/timezones.htm


        :param cluster_time_zone: The cluster_time_zone of this CreateCloudAutonomousVmClusterDetails.
        :type: str
        """
        self._cluster_time_zone = cluster_time_zone

    @property
    def license_model(self):
        """
        Gets the license_model of this CreateCloudAutonomousVmClusterDetails.
        The Oracle license model that applies to the Oracle Autonomous Database. Bring your own license (BYOL) allows you to apply your current on-premises Oracle software licenses to equivalent, highly automated Oracle PaaS and IaaS services in the cloud.
        License Included allows you to subscribe to new Oracle Database software licenses and the Database service.
        Note that when provisioning an Autonomous Database on `dedicated Exadata infrastructure`__, this attribute must be null because the attribute is already set at the
        Autonomous Exadata Infrastructure level. When using `shared Exadata infrastructure`__, if a value is not specified, the system will supply the value of `BRING_YOUR_OWN_LICENSE`.

        __ https://docs.oracle.com/en/cloud/paas/autonomous-database/index.html
        __ https://docs.oracle.com/en/cloud/paas/autonomous-database/index.html

        Allowed values for this property are: "LICENSE_INCLUDED", "BRING_YOUR_OWN_LICENSE"


        :return: The license_model of this CreateCloudAutonomousVmClusterDetails.
        :rtype: str
        """
        return self._license_model

    @license_model.setter
    def license_model(self, license_model):
        """
        Sets the license_model of this CreateCloudAutonomousVmClusterDetails.
        The Oracle license model that applies to the Oracle Autonomous Database. Bring your own license (BYOL) allows you to apply your current on-premises Oracle software licenses to equivalent, highly automated Oracle PaaS and IaaS services in the cloud.
        License Included allows you to subscribe to new Oracle Database software licenses and the Database service.
        Note that when provisioning an Autonomous Database on `dedicated Exadata infrastructure`__, this attribute must be null because the attribute is already set at the
        Autonomous Exadata Infrastructure level. When using `shared Exadata infrastructure`__, if a value is not specified, the system will supply the value of `BRING_YOUR_OWN_LICENSE`.

        __ https://docs.oracle.com/en/cloud/paas/autonomous-database/index.html
        __ https://docs.oracle.com/en/cloud/paas/autonomous-database/index.html


        :param license_model: The license_model of this CreateCloudAutonomousVmClusterDetails.
        :type: str
        """
        allowed_values = ["LICENSE_INCLUDED", "BRING_YOUR_OWN_LICENSE"]
        if not value_allowed_none_or_none_sentinel(license_model, allowed_values):
            raise ValueError(
                "Invalid value for `license_model`, must be None or one of {0}"
                .format(allowed_values)
            )
        self._license_model = license_model

    @property
    def nsg_ids(self):
        """
        Gets the nsg_ids of this CreateCloudAutonomousVmClusterDetails.
        The list of `OCIDs`__ for the network security groups (NSGs) to which this resource belongs. Setting this to an empty list removes all resources from all NSGs. For more information about NSGs, see `Security Rules`__.
        **NsgIds restrictions:**
        - A network security group (NSG) is optional for Autonomous Databases with private access. The nsgIds list can be empty.

        __ https://docs.cloud.oracle.com/Content/General/Concepts/identifiers.htm
        __ https://docs.cloud.oracle.com/Content/Network/Concepts/securityrules.htm


        :return: The nsg_ids of this CreateCloudAutonomousVmClusterDetails.
        :rtype: list[str]
        """
        return self._nsg_ids

    @nsg_ids.setter
    def nsg_ids(self, nsg_ids):
        """
        Sets the nsg_ids of this CreateCloudAutonomousVmClusterDetails.
        The list of `OCIDs`__ for the network security groups (NSGs) to which this resource belongs. Setting this to an empty list removes all resources from all NSGs. For more information about NSGs, see `Security Rules`__.
        **NsgIds restrictions:**
        - A network security group (NSG) is optional for Autonomous Databases with private access. The nsgIds list can be empty.

        __ https://docs.cloud.oracle.com/Content/General/Concepts/identifiers.htm
        __ https://docs.cloud.oracle.com/Content/Network/Concepts/securityrules.htm


        :param nsg_ids: The nsg_ids of this CreateCloudAutonomousVmClusterDetails.
        :type: list[str]
        """
        self._nsg_ids = nsg_ids

    @property
    def freeform_tags(self):
        """
        Gets the freeform_tags of this CreateCloudAutonomousVmClusterDetails.
        Free-form tags for this resource. Each tag is a simple key-value pair with no predefined name, type, or namespace.
        For more information, see `Resource Tags`__.

        Example: `{\"Department\": \"Finance\"}`

        __ https://docs.cloud.oracle.com/Content/General/Concepts/resourcetags.htm


        :return: The freeform_tags of this CreateCloudAutonomousVmClusterDetails.
        :rtype: dict(str, str)
        """
        return self._freeform_tags

    @freeform_tags.setter
    def freeform_tags(self, freeform_tags):
        """
        Sets the freeform_tags of this CreateCloudAutonomousVmClusterDetails.
        Free-form tags for this resource. Each tag is a simple key-value pair with no predefined name, type, or namespace.
        For more information, see `Resource Tags`__.

        Example: `{\"Department\": \"Finance\"}`

        __ https://docs.cloud.oracle.com/Content/General/Concepts/resourcetags.htm


        :param freeform_tags: The freeform_tags of this CreateCloudAutonomousVmClusterDetails.
        :type: dict(str, str)
        """
        self._freeform_tags = freeform_tags

    @property
    def defined_tags(self):
        """
        Gets the defined_tags of this CreateCloudAutonomousVmClusterDetails.
        Defined tags for this resource. Each key is predefined and scoped to a namespace.
        For more information, see `Resource Tags`__.

        __ https://docs.cloud.oracle.com/Content/General/Concepts/resourcetags.htm


        :return: The defined_tags of this CreateCloudAutonomousVmClusterDetails.
        :rtype: dict(str, dict(str, object))
        """
        return self._defined_tags

    @defined_tags.setter
    def defined_tags(self, defined_tags):
        """
        Sets the defined_tags of this CreateCloudAutonomousVmClusterDetails.
        Defined tags for this resource. Each key is predefined and scoped to a namespace.
        For more information, see `Resource Tags`__.

        __ https://docs.cloud.oracle.com/Content/General/Concepts/resourcetags.htm


        :param defined_tags: The defined_tags of this CreateCloudAutonomousVmClusterDetails.
        :type: dict(str, dict(str, object))
        """
        self._defined_tags = defined_tags

    def __repr__(self):
        return formatted_flat_dict(self)

    def __eq__(self, other):
        if other is None:
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        return not self == other



# coding: utf-8
# Copyright (c) 2016, 2022, Oracle and/or its affiliates.  All rights reserved.
# This software is dual-licensed to you under the Universal Permissive License (UPL) 1.0 as shown at https://oss.oracle.com/licenses/upl or Apache License 2.0 as shown at http://www.apache.org/licenses/LICENSE-2.0. You may choose either license.


from oci.util import formatted_flat_dict, NONE_SENTINEL, value_allowed_none_or_none_sentinel  # noqa: F401
from oci.decorators import init_model_state_from_kwargs


@init_model_state_from_kwargs
class MutualTlsDetails(object):
    """
    Properties used to configure client mTLS verification when API Consumer makes connection to the gateway.
    """

    def __init__(self, **kwargs):
        """
        Initializes a new MutualTlsDetails object with values from keyword arguments.
        The following keyword arguments are supported (corresponding to the getters/setters of this class):

        :param is_verified_certificate_required:
            The value to assign to the is_verified_certificate_required property of this MutualTlsDetails.
        :type is_verified_certificate_required: bool

        :param allowed_sans:
            The value to assign to the allowed_sans property of this MutualTlsDetails.
        :type allowed_sans: list[str]

        """
        self.swagger_types = {
            'is_verified_certificate_required': 'bool',
            'allowed_sans': 'list[str]'
        }

        self.attribute_map = {
            'is_verified_certificate_required': 'isVerifiedCertificateRequired',
            'allowed_sans': 'allowedSans'
        }

        self._is_verified_certificate_required = None
        self._allowed_sans = None

    @property
    def is_verified_certificate_required(self):
        """
        Gets the is_verified_certificate_required of this MutualTlsDetails.
        Determines whether to enable client verification when API Consumer makes connection to the gateway.


        :return: The is_verified_certificate_required of this MutualTlsDetails.
        :rtype: bool
        """
        return self._is_verified_certificate_required

    @is_verified_certificate_required.setter
    def is_verified_certificate_required(self, is_verified_certificate_required):
        """
        Sets the is_verified_certificate_required of this MutualTlsDetails.
        Determines whether to enable client verification when API Consumer makes connection to the gateway.


        :param is_verified_certificate_required: The is_verified_certificate_required of this MutualTlsDetails.
        :type: bool
        """
        self._is_verified_certificate_required = is_verified_certificate_required

    @property
    def allowed_sans(self):
        """
        Gets the allowed_sans of this MutualTlsDetails.
        Allowed list of CN or SAN which will be used for verification of certificate.


        :return: The allowed_sans of this MutualTlsDetails.
        :rtype: list[str]
        """
        return self._allowed_sans

    @allowed_sans.setter
    def allowed_sans(self, allowed_sans):
        """
        Sets the allowed_sans of this MutualTlsDetails.
        Allowed list of CN or SAN which will be used for verification of certificate.


        :param allowed_sans: The allowed_sans of this MutualTlsDetails.
        :type: list[str]
        """
        self._allowed_sans = allowed_sans

    def __repr__(self):
        return formatted_flat_dict(self)

    def __eq__(self, other):
        if other is None:
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        return not self == other



# coding: utf-8
# Copyright (c) 2016, 2022, Oracle and/or its affiliates.  All rights reserved.
# This software is dual-licensed to you under the Universal Permissive License (UPL) 1.0 as shown at https://oss.oracle.com/licenses/upl or Apache License 2.0 as shown at http://www.apache.org/licenses/LICENSE-2.0. You may choose either license.


from oci.util import formatted_flat_dict, NONE_SENTINEL, value_allowed_none_or_none_sentinel  # noqa: F401
from oci.decorators import init_model_state_from_kwargs


@init_model_state_from_kwargs
class InvoiceLineSummary(object):
    """
    Product items of the invoice
    """

    def __init__(self, **kwargs):
        """
        Initializes a new InvoiceLineSummary object with values from keyword arguments.
        The following keyword arguments are supported (corresponding to the getters/setters of this class):

        :param product:
            The value to assign to the product property of this InvoiceLineSummary.
        :type product: str

        :param order_no:
            The value to assign to the order_no property of this InvoiceLineSummary.
        :type order_no: str

        :param part_number:
            The value to assign to the part_number property of this InvoiceLineSummary.
        :type part_number: str

        :param time_start:
            The value to assign to the time_start property of this InvoiceLineSummary.
        :type time_start: datetime

        :param time_end:
            The value to assign to the time_end property of this InvoiceLineSummary.
        :type time_end: datetime

        :param quantity:
            The value to assign to the quantity property of this InvoiceLineSummary.
        :type quantity: float

        :param net_unit_price:
            The value to assign to the net_unit_price property of this InvoiceLineSummary.
        :type net_unit_price: float

        :param total_price:
            The value to assign to the total_price property of this InvoiceLineSummary.
        :type total_price: float

        :param currency:
            The value to assign to the currency property of this InvoiceLineSummary.
        :type currency: oci.osp_gateway.models.Currency

        """
        self.swagger_types = {
            'product': 'str',
            'order_no': 'str',
            'part_number': 'str',
            'time_start': 'datetime',
            'time_end': 'datetime',
            'quantity': 'float',
            'net_unit_price': 'float',
            'total_price': 'float',
            'currency': 'Currency'
        }

        self.attribute_map = {
            'product': 'product',
            'order_no': 'orderNo',
            'part_number': 'partNumber',
            'time_start': 'timeStart',
            'time_end': 'timeEnd',
            'quantity': 'quantity',
            'net_unit_price': 'netUnitPrice',
            'total_price': 'totalPrice',
            'currency': 'currency'
        }

        self._product = None
        self._order_no = None
        self._part_number = None
        self._time_start = None
        self._time_end = None
        self._quantity = None
        self._net_unit_price = None
        self._total_price = None
        self._currency = None

    @property
    def product(self):
        """
        **[Required]** Gets the product of this InvoiceLineSummary.
        Product of the item


        :return: The product of this InvoiceLineSummary.
        :rtype: str
        """
        return self._product

    @product.setter
    def product(self, product):
        """
        Sets the product of this InvoiceLineSummary.
        Product of the item


        :param product: The product of this InvoiceLineSummary.
        :type: str
        """
        self._product = product

    @property
    def order_no(self):
        """
        Gets the order_no of this InvoiceLineSummary.
        Product of the item


        :return: The order_no of this InvoiceLineSummary.
        :rtype: str
        """
        return self._order_no

    @order_no.setter
    def order_no(self, order_no):
        """
        Sets the order_no of this InvoiceLineSummary.
        Product of the item


        :param order_no: The order_no of this InvoiceLineSummary.
        :type: str
        """
        self._order_no = order_no

    @property
    def part_number(self):
        """
        Gets the part_number of this InvoiceLineSummary.
        Part number


        :return: The part_number of this InvoiceLineSummary.
        :rtype: str
        """
        return self._part_number

    @part_number.setter
    def part_number(self, part_number):
        """
        Sets the part_number of this InvoiceLineSummary.
        Part number


        :param part_number: The part_number of this InvoiceLineSummary.
        :type: str
        """
        self._part_number = part_number

    @property
    def time_start(self):
        """
        Gets the time_start of this InvoiceLineSummary.
        Start date


        :return: The time_start of this InvoiceLineSummary.
        :rtype: datetime
        """
        return self._time_start

    @time_start.setter
    def time_start(self, time_start):
        """
        Sets the time_start of this InvoiceLineSummary.
        Start date


        :param time_start: The time_start of this InvoiceLineSummary.
        :type: datetime
        """
        self._time_start = time_start

    @property
    def time_end(self):
        """
        Gets the time_end of this InvoiceLineSummary.
        End date


        :return: The time_end of this InvoiceLineSummary.
        :rtype: datetime
        """
        return self._time_end

    @time_end.setter
    def time_end(self, time_end):
        """
        Sets the time_end of this InvoiceLineSummary.
        End date


        :param time_end: The time_end of this InvoiceLineSummary.
        :type: datetime
        """
        self._time_end = time_end

    @property
    def quantity(self):
        """
        Gets the quantity of this InvoiceLineSummary.
        Quantity of the ordered product


        :return: The quantity of this InvoiceLineSummary.
        :rtype: float
        """
        return self._quantity

    @quantity.setter
    def quantity(self, quantity):
        """
        Sets the quantity of this InvoiceLineSummary.
        Quantity of the ordered product


        :param quantity: The quantity of this InvoiceLineSummary.
        :type: float
        """
        self._quantity = quantity

    @property
    def net_unit_price(self):
        """
        Gets the net_unit_price of this InvoiceLineSummary.
        Unit price of the ordered product


        :return: The net_unit_price of this InvoiceLineSummary.
        :rtype: float
        """
        return self._net_unit_price

    @net_unit_price.setter
    def net_unit_price(self, net_unit_price):
        """
        Sets the net_unit_price of this InvoiceLineSummary.
        Unit price of the ordered product


        :param net_unit_price: The net_unit_price of this InvoiceLineSummary.
        :type: float
        """
        self._net_unit_price = net_unit_price

    @property
    def total_price(self):
        """
        Gets the total_price of this InvoiceLineSummary.
        Total price of the ordered product (Net unit price x quantity)


        :return: The total_price of this InvoiceLineSummary.
        :rtype: float
        """
        return self._total_price

    @total_price.setter
    def total_price(self, total_price):
        """
        Sets the total_price of this InvoiceLineSummary.
        Total price of the ordered product (Net unit price x quantity)


        :param total_price: The total_price of this InvoiceLineSummary.
        :type: float
        """
        self._total_price = total_price

    @property
    def currency(self):
        """
        Gets the currency of this InvoiceLineSummary.

        :return: The currency of this InvoiceLineSummary.
        :rtype: oci.osp_gateway.models.Currency
        """
        return self._currency

    @currency.setter
    def currency(self, currency):
        """
        Sets the currency of this InvoiceLineSummary.

        :param currency: The currency of this InvoiceLineSummary.
        :type: oci.osp_gateway.models.Currency
        """
        self._currency = currency

    def __repr__(self):
        return formatted_flat_dict(self)

    def __eq__(self, other):
        if other is None:
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        return not self == other
